@@ -135,7 +135,12 @@ class DhcpAgent(manager.Manager):
                           'that the network and/or its subnet(s) still exist.')
                         % {'net_id': network.id, 'action': action})
         except Exception as e:
-            self.schedule_resync(e)
+            if getattr(e, 'exc_type', '') != 'IpAddressGenerationFailure':
+                # Don't resync if port could not be created because of an IP
+                # allocation failure. When the subnet is updated with a new
+                # allocation pool or a port is  deleted to free up an IP, this
+                # will automatically be retried on the notification
+                self.schedule_resync(e)
             if (isinstance(e, n_rpc.RemoteError)
                 and e.exc_type == 'NetworkNotFound'
                 or isinstance(e, exceptions.NetworkNotFound)):
@@ -346,8 +351,9 @@ class DhcpAgent(manager.Manager):
         # be started for the router attached to the network
         if self.conf.enable_metadata_network:
             router_ports = [port for port in network.ports
-                            if (port.device_owner ==
-                                constants.DEVICE_OWNER_ROUTER_INTF)]
+                            if (port.device_owner in
+                                (constants.DEVICE_OWNER_ROUTER_INTF,
+                                 constants.DEVICE_OWNER_DVR_INTERFACE))]
             if router_ports:
                 # Multiple router ports should not be allowed
                 if len(router_ports) > 1:
