@@ -17,8 +17,10 @@ import os
 import shutil
 import signal
 
+import netaddr
 from oslo.config import cfg
 
+from neutron.agent.linux import ip_lib
 from neutron.agent.linux import keepalived
 from neutron.common import constants as l3_constants
 from neutron.openstack.common.gettextutils import _LE
@@ -102,14 +104,17 @@ class AgentMixin(object):
         if not os.path.isdir(ha_full_path):
             os.makedirs(ha_full_path, 0o755)
 
-    def _init_keepalived_manager(self, ri):
-        ri.keepalived_manager = keepalived.KeepalivedManager(
+    def get_keepalived_manager(self, ri):
+        return keepalived.KeepalivedManager(
             ri.router['id'],
             keepalived.KeepalivedConf(),
             conf_path=self.conf.ha_confs_path,
             namespace=ri.ns_name,
             root_helper=self.root_helper)
 
+    def _init_keepalived_manager(self, ri):
+        ri.keepalived_manager = self.get_keepalived_manager(ri)
+
         config = ri.keepalived_manager.config
 
         interface_name = self.get_ha_device_name(ri.ha_port['id'])
@@ -167,9 +172,9 @@ class AgentMixin(object):
                            prefix=HA_DEV_PREFIX)
         ri.ha_port = None
 
-    def _add_vip(self, ri, ip_cidr, interface):
+    def _add_vip(self, ri, ip_cidr, interface, scope=None):
         instance = ri.keepalived_manager.config.get_instance(ri.ha_vr_id)
-        instance.add_vip(ip_cidr, interface)
+        instance.add_vip(ip_cidr, interface, scope)
 
     def _remove_vip(self, ri, ip_cidr):
         instance = ri.keepalived_manager.config.get_instance(ri.ha_vr_id)
@@ -202,18 +207,57 @@ class AgentMixin(object):
     def _add_default_gw_virtual_route(self, ri, ex_gw_port, interface_name):
         gw_ip = ex_gw_port['subnet']['gateway_ip']
         if gw_ip:
+            default_gw = ('0.0.0.0/0' if netaddr.IPAddress(gw_ip).version == 4
+                          else '::/0')
             instance = ri.keepalived_manager.config.get_instance(ri.ha_vr_id)
             instance.virtual_routes = (
                 [route for route in instance.virtual_routes
-                 if route.destination != '0.0.0.0/0'])
+                 if route.destination != default_gw])
             instance.virtual_routes.append(
                 keepalived.KeepalivedVirtualRoute(
-                    '0.0.0.0/0', gw_ip, interface_name))
+                    default_gw, gw_ip, interface_name))
 
     def _ha_external_gateway_added(self, ri, ex_gw_port, interface_name):
         self._add_vip(ri, ex_gw_port['ip_cidr'], interface_name)
         self._add_default_gw_virtual_route(ri, ex_gw_port, interface_name)
 
+    def _should_delete_ipv6_lladdr(self, ri, ipv6_lladdr):
+        """Only the master should have any IP addresses configured.
+        Let keepalived manage IPv6 link local addresses, the same way we let
+        it manage IPv4 addresses. In order to do that, we must delete
+        the address first as it is autoconfigured by the kernel.
+        """
+        process = keepalived.KeepalivedManager.get_process(
+            self.conf,
+            ri.router_id,
+            self.root_helper,
+            ri.ns_name,
+            self.conf.ha_confs_path)
+        if process.active:
+            manager = self.get_keepalived_manager(ri)
+            conf = manager.get_conf_on_disk()
+            managed_by_keepalived = conf and ipv6_lladdr in conf
+            if managed_by_keepalived:
+                return False
+        return True
+
+    def _ha_disable_addressing_on_interface(self, ri, interface_name):
+        """Disable IPv6 link local addressing on the device and add it as
+        a VIP to keepalived. This means that the IPv6 link local address
+        will only be present on the master.
+        """
+        device = ip_lib.IPDevice(interface_name, self.root_helper, ri.ns_name)
+        ipv6_lladdr = self._get_ipv6_lladdr(device.link.address)
+
+        if self._should_delete_ipv6_lladdr(ri, ipv6_lladdr):
+            device.addr.flush()
+
+        self._remove_vip(ri, ipv6_lladdr)
+        self._add_vip(ri, ipv6_lladdr, interface_name, scope='link')
+
+    def _get_ipv6_lladdr(self, mac_addr):
+        return '%s/64' % netaddr.EUI(mac_addr).ipv6_link_local()
+
     def _ha_external_gateway_removed(self, ri, interface_name):
         self._clear_vips(ri, interface_name)
 
@@ -221,8 +265,9 @@ class AgentMixin(object):
         instance = ri.keepalived_manager.config.get_instance(ri.ha_vr_id)
 
         # Filter out all of the old routes while keeping only the default route
+        default_gw = ('::/0', '0.0.0.0/0')
         instance.virtual_routes = [route for route in instance.virtual_routes
-                                   if route.destination == '0.0.0.0/0']
+                                   if route.destination in default_gw]
         for route in new_routes:
             instance.virtual_routes.append(keepalived.KeepalivedVirtualRoute(
                 route['destination'],
