@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Red Hat, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -17,7 +15,6 @@
 import eventlet
 import eventlet.event
 import eventlet.queue
-import eventlet.timeout
 
 from neutron.agent.linux import utils
 from neutron.openstack.common import log as logging
@@ -129,23 +126,25 @@ class AsyncProcess(object):
 
     def _get_pid_to_kill(self):
         pid = self._process.pid
-        # If root helper was used, two processes will be created:
+        # If root helper was used, two or more processes will be created:
         #
         #  - a root helper process (e.g. sudo myscript)
         #  - possibly a rootwrap script (e.g. neutron-rootwrap)
         #  - a child process (e.g. myscript)
         #
         # Killing the root helper process will leave the child process
-        # as a zombie, so the only way to ensure that both die is to
-        # target the child process directly.
+        # running, re-parented to init, so the only way to ensure that both
+        # die is to target the child process directly.
         if self.root_helper:
             try:
                 pid = utils.find_child_pids(pid)[0]
             except IndexError:
-                # Process is already dead or pid == None.
+                # Process is already dead
                 return None
             while True:
                 try:
+                    # We shouldn't have more than one child per process
+                    # so keep getting the children of the first one
                     pid = utils.find_child_pids(pid)[0]
                 except IndexError:
                     # Last process in the tree, return it
@@ -183,7 +182,7 @@ class AsyncProcess(object):
                 if not callback():
                     break
             except Exception:
-                LOG.exception(_('An error occured while communicating '
+                LOG.exception(_('An error occurred while communicating '
                                 'with async process [%s].'), self.cmd)
                 break
             # Ensure that watching a process with lots of output does
