@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2011 OpenStack Foundation.
 # Copyright 2011 Justin Santa Barbara
 # All Rights Reserved.
@@ -16,7 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from abc import ABCMeta
+import abc
 import imp
 import itertools
 import os
@@ -30,7 +28,7 @@ import webob.exc
 from neutron.api.v2 import attributes
 from neutron.common import exceptions
 import neutron.extensions
-from neutron.manager import NeutronManager
+from neutron import manager
 from neutron.openstack.common import log as logging
 from neutron import wsgi
 
@@ -38,7 +36,7 @@ from neutron import wsgi
 LOG = logging.getLogger(__name__)
 
 
-@six.add_metaclass(ABCMeta)
+@six.add_metaclass(abc.ABCMeta)
 class PluginInterface(object):
 
     @classmethod
@@ -52,6 +50,10 @@ class PluginInterface(object):
         marked with the abstractmethod decorator is
         provided by the plugin class.
         """
+
+        if not cls.__abstractmethods__:
+            return NotImplemented
+
         for method in cls.__abstractmethods__:
             if any(method in base.__dict__ for base in klass.__mro__):
                 continue
@@ -146,7 +148,7 @@ class ExtensionDescriptor(object):
     def get_plugin_interface(self):
         """Returns an abstract class which defines contract for the plugin.
 
-        The abstract class should inherit from extesnions.PluginInterface,
+        The abstract class should inherit from extensions.PluginInterface,
         Methods in this abstract class  should be decorated as abstractmethod
         """
         return None
@@ -514,12 +516,6 @@ class ExtensionManager(object):
         except AttributeError as ex:
             LOG.exception(_("Exception loading extension: %s"), unicode(ex))
             return False
-        if hasattr(extension, 'check_env'):
-            try:
-                extension.check_env()
-            except exceptions.InvalidExtensionEnv as ex:
-                LOG.warn(_("Exception loading extension: %s"), unicode(ex))
-                return False
         return True
 
     def _load_all_extensions(self):
@@ -544,7 +540,7 @@ class ExtensionManager(object):
         # Neutron Servers
         for f in sorted(os.listdir(path)):
             try:
-                LOG.info(_('Loading extension file: %s'), f)
+                LOG.debug(_('Loading extension file: %s'), f)
                 mod_name, file_ext = os.path.splitext(os.path.split(f)[-1])
                 ext_path = os.path.join(path, f)
                 if file_ext.lower() == '.py' and not mod_name.startswith('_'):
@@ -619,7 +615,7 @@ class PluginAwareExtensionManager(ExtensionManager):
     def get_instance(cls):
         if cls._instance is None:
             cls._instance = cls(get_extensions_path(),
-                                NeutronManager.get_service_plugins())
+                                manager.NeutronManager.get_service_plugins())
         return cls._instance
 
     def check_if_plugin_extensions_loaded(self):
@@ -681,6 +677,6 @@ def get_extensions_path():
 
 
 def append_api_extensions_path(paths):
-    paths = [cfg.CONF.api_extensions_path] + paths
+    paths = list(set([cfg.CONF.api_extensions_path] + paths))
     cfg.CONF.set_override('api_extensions_path',
                           ':'.join([p for p in paths if p]))
