@@ -335,3 +335,12 @@ class DeviceIDNotOwnedByTenant(Conflict):
 
 class InvalidCIDR(BadRequest):
     message = _("Invalid CIDR %(input)s given as IP prefix")
+
+
+class RetryRequest(Exception):
+    """Error raised when DB operation needs to be retried.
+
+    That could be intentionally raised by the code without any real DB errors.
+    """
+    def __init__(self, inner_exc):
+        self.inner_exc = inner_exc
