@@ -20,6 +20,7 @@ import os
 
 import netaddr
 
+from neutron.common import constants
 from neutron.openstack.common.gettextutils import _LI
 from neutron.openstack.common import log
 
@@ -61,3 +62,10 @@ def is_enabled():
         if not _IS_IPV6_ENABLED:
             LOG.info(_LI("IPv6 is not enabled on this system."))
     return _IS_IPV6_ENABLED
+
+
+def is_auto_address_subnet(subnet):
+    """Check if subnet is an auto address subnet."""
+    modes = [constants.IPV6_SLAAC, constants.DHCPV6_STATELESS]
+    return (subnet['ipv6_address_mode'] in modes
+            or subnet['ipv6_ra_mode'] in modes)
