@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright (c) 2013 OpenStack Foundation.
 # All Rights Reserved.
 #
@@ -25,6 +23,7 @@ from neutron.common import constants
 from neutron.common import utils
 from neutron.db import agents_db
 from neutron.db import model_base
+from neutron.extensions import agent as ext_agent
 from neutron.extensions import dhcpagentscheduler
 from neutron.openstack.common import log as logging
 
@@ -100,7 +99,7 @@ class AgentSchedulerDbMixin(agents_db.AgentDbMixin):
 class DhcpAgentSchedulerDbMixin(dhcpagentscheduler
                                 .DhcpAgentSchedulerPluginBase,
                                 AgentSchedulerDbMixin):
-    """Mixin class to add DHCP agent scheduler extension to db_plugin_base_v2.
+    """Mixin class to add DHCP agent scheduler extension to db_base_plugin_v2.
     """
 
     network_scheduler = None
@@ -186,8 +185,13 @@ class DhcpAgentSchedulerDbMixin(dhcpagentscheduler
             return {'networks': []}
 
     def list_active_networks_on_active_dhcp_agent(self, context, host):
-        agent = self._get_agent_by_type_and_host(
-            context, constants.AGENT_TYPE_DHCP, host)
+        try:
+            agent = self._get_agent_by_type_and_host(
+                context, constants.AGENT_TYPE_DHCP, host)
+        except ext_agent.AgentNotFoundByTypeHost:
+            LOG.debug("DHCP Agent not found on host %s", host)
+            return []
+
         if not agent.admin_state_up:
             return []
         query = context.session.query(NetworkDhcpAgentBinding.network_id)
