@@ -29,7 +29,13 @@ EXTENDED_ATTRIBUTES_2_0 = {
                  {'type:dict_or_nodata':
                   {'network_id': {'type:uuid': None, 'required': True},
                    'enable_snat': {'type:boolean': None, 'required': False,
-                                   'convert_to': attrs.convert_to_boolean}}
+                                   'convert_to': attrs.convert_to_boolean},
+                   'external_fixed_ips': {
+                       'convert_list_to': attrs.convert_kvp_list_to_dict,
+                       'validate': {'type:fixed_ips': None},
+                       'default': None,
+                       'required': False}
+                   }
                   }}}}
 
 
