@@ -37,6 +37,12 @@ author_tag_re = (re.compile("^\s*#\s*@?(a|A)uthor"),
                  re.compile("^\.\.\s+moduleauthor::"))
 
 
+oslo_namespace_imports_underscore = re.compile(
+    r"import[\s]+oslo_[^\s]+")
+oslo_namespace_imports_from_underscore = re.compile(
+    r"from[\s]+oslo_[^\s]+[\s]+import[\s]+")
+
+
 def validate_log_translations(logical_line, physical_line, filename):
     # Translations are not required in the test directory
     if "neutron/tests" in filename:
@@ -79,7 +85,21 @@ def no_author_tags(physical_line):
             return pos, "N322: Don't use author tags"
 
 
+def check_oslo_namespace_imports(logical_line):
+    if re.match(oslo_namespace_imports_underscore, logical_line):
+        msg = ("N323: '%s' must be used instead of '%s'.") % (
+               logical_line.replace('import', 'from').replace('_', ' import '),
+               logical_line)
+        yield(0, msg)
+    elif re.match(oslo_namespace_imports_from_underscore, logical_line):
+        msg = ("N323: '%s' must be used instead of '%s'.") % (
+               logical_line.replace('_', '.'),
+               logical_line)
+        yield(0, msg)
+
+
 def factory(register):
     register(validate_log_translations)
     register(use_jsonutils)
     register(no_author_tags)
+    register(check_oslo_namespace_imports)
