@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Cloudbase Solutions SRL
 # Copyright 2013 Pedro Navarro Perez
 # All Rights Reserved.
@@ -15,8 +13,6 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-# @author: Pedro Navarro Perez
-# @author: Alessandro Pilotti, Cloudbase Solutions Srl
 
 import sys
 import time
@@ -45,6 +41,10 @@ WMI_JOB_STATE_COMPLETED = 7
 class HyperVUtils(object):
 
     _ETHERNET_SWITCH_PORT = 'Msvm_SwitchPort'
+    _SWITCH_LAN_ENDPOINT = 'Msvm_SwitchLanEndpoint'
+    _VIRTUAL_SWITCH = 'Msvm_VirtualSwitch'
+    _BINDS_TO = 'Msvm_BindsTo'
+    _VLAN_ENDPOINT_SET_DATA = 'Msvm_VLANEndpointSettingData'
 
     _wmi_namespace = '//./root/virtualization'
 
@@ -173,7 +173,7 @@ class HyperVUtils(object):
         pass
 
     def disconnect_switch_port(
-            self, vswitch_name, switch_port_name, delete_port):
+            self, vswitch_name, switch_port_name, vnic_deleted, delete_port):
         """Disconnects the switch port."""
         switch_svc = self._conn.Msvm_VirtualSwitchManagementService()[0]
         switch_port_path = self._get_switch_port_path_by_name(
@@ -182,16 +182,17 @@ class HyperVUtils(object):
             # Port not found. It happens when the VM was already deleted.
             return
 
-        (ret_val, ) = switch_svc.DisconnectSwitchPort(
-            SwitchPort=switch_port_path)
-        if ret_val != 0:
-            data = {'switch_port_name': switch_port_name,
-                    'vswitch_name': vswitch_name,
-                    'ret_val': ret_val}
-            raise HyperVException(
-                msg=_('Failed to disconnect port %(switch_port_name)s '
-                      'from switch %(vswitch_name)s '
-                      'with error %(ret_val)s') % data)
+        if not vnic_deleted:
+            (ret_val, ) = switch_svc.DisconnectSwitchPort(
+                SwitchPort=switch_port_path)
+            if ret_val != 0:
+                data = {'switch_port_name': switch_port_name,
+                        'vswitch_name': vswitch_name,
+                        'ret_val': ret_val}
+                raise HyperVException(
+                    msg=_('Failed to disconnect port %(switch_port_name)s '
+                          'from switch %(vswitch_name)s '
+                          'with error %(ret_val)s') % data)
         if delete_port:
             (ret_val, ) = switch_svc.DeleteSwitchPort(
                 SwitchPort=switch_port_path)
@@ -211,17 +212,21 @@ class HyperVUtils(object):
                                   vswitch_name)
         return vswitch[0]
 
-    def _get_vswitch_external_port(self, vswitch):
-        vswitch_ports = vswitch.associators(
-            wmi_result_class=self._ETHERNET_SWITCH_PORT)
-        for vswitch_port in vswitch_ports:
-            lan_endpoints = vswitch_port.associators(
+    def _get_vswitch_external_port(self, vswitch_name):
+        ext_ports = self._conn.Msvm_ExternalEthernetPort()
+        for ext_port in ext_ports:
+            lan_endpoint_list = ext_port.associators(
                 wmi_result_class='Msvm_SwitchLanEndpoint')
-            if lan_endpoints:
-                ext_port = lan_endpoints[0].associators(
-                    wmi_result_class='Msvm_ExternalEthernetPort')
-                if ext_port:
-                    return vswitch_port
+            if lan_endpoint_list:
+                vswitch_port_list = lan_endpoint_list[0].associators(
+                    wmi_result_class=self._ETHERNET_SWITCH_PORT)
+                if vswitch_port_list:
+                    vswitch_port = vswitch_port_list[0]
+                    vswitch_list = vswitch_port.associators(
+                        wmi_result_class='Msvm_VirtualSwitch')
+                    if (vswitch_list and
+                            vswitch_list[0].ElementName == vswitch_name):
+                        return vswitch_port
 
     def set_vswitch_port_vlan_id(self, vlan_id, switch_port_name):
         vlan_endpoint_settings = self._conn.Msvm_VLANEndpointSettingData(
@@ -230,6 +235,21 @@ class HyperVUtils(object):
             vlan_endpoint_settings.AccessVLAN = vlan_id
             vlan_endpoint_settings.put()
 
+    def set_switch_external_port_trunk_vlan(self, vswitch_name, vlan_id,
+                                            desired_endpoint_mode):
+        vswitch_external_port = self._get_vswitch_external_port(vswitch_name)
+        if vswitch_external_port:
+            vlan_endpoint = vswitch_external_port.associators(
+                wmi_association_class=self._BINDS_TO)[0]
+            if vlan_endpoint.DesiredEndpointMode != desired_endpoint_mode:
+                vlan_endpoint.DesiredEndpointMode = desired_endpoint_mode
+                vlan_endpoint.put()
+            vlan_endpoint_settings = vlan_endpoint.associators(
+                wmi_result_class=self._VLAN_ENDPOINT_SET_DATA)[0]
+            if vlan_id not in vlan_endpoint_settings.TrunkedVLANList:
+                vlan_endpoint_settings.TrunkedVLANList += (vlan_id,)
+                vlan_endpoint_settings.put()
+
     def _get_switch_port_path_by_name(self, switch_port_name):
         vswitch = self._conn.Msvm_SwitchPort(ElementName=switch_port_name)
         if vswitch:
