@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Cloudbase Solutions SRL
 # All Rights Reserved.
 #
@@ -14,11 +12,10 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-# @author: Alessandro Pilotti, Cloudbase Solutions Srl
 
 from sqlalchemy import Boolean, Column, ForeignKey, Integer, String
 
-from neutron.db.models_v2 import model_base
+from neutron.db import model_base
 
 
 class VlanAllocation(model_base.BASEV2):
