@@ -13,8 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from abc import ABCMeta, abstractmethod, abstractproperty
-
+import abc
 import six
 
 # The following keys are used in the segment dictionaries passed via
@@ -28,7 +27,7 @@ PHYSICAL_NETWORK = 'physical_network'
 SEGMENTATION_ID = 'segmentation_id'
 
 
-@six.add_metaclass(ABCMeta)
+@six.add_metaclass(abc.ABCMeta)
 class TypeDriver(object):
     """Define stable abstract interface for ML2 type drivers.
 
@@ -46,7 +45,7 @@ class TypeDriver(object):
     either be excluded or stored as None.
     """
 
-    @abstractmethod
+    @abc.abstractmethod
     def get_type(self):
         """Get driver's network type.
 
@@ -54,7 +53,7 @@ class TypeDriver(object):
         """
         pass
 
-    @abstractmethod
+    @abc.abstractmethod
     def initialize(self):
         """Perform driver initialization.
 
@@ -64,7 +63,15 @@ class TypeDriver(object):
         """
         pass
 
-    @abstractmethod
+    @abc.abstractmethod
+    def is_partial_segment(self, segment):
+        """Return True if segment is a partially specified segment.
+
+        :param segment: segment dictionary
+        :returns: boolean
+        """
+
+    @abc.abstractmethod
     def validate_provider_segment(self, segment):
         """Validate attributes of a provider network segment.
 
@@ -84,12 +91,13 @@ class TypeDriver(object):
         """
         pass
 
-    @abstractmethod
+    @abc.abstractmethod
     def reserve_provider_segment(self, session, segment):
         """Reserve resource associated with a provider network segment.
 
         :param session: database session
-        :param segment: segment dictionary using keys defined above
+        :param segment: segment dictionary
+        :returns: segment dictionary
 
         Called inside transaction context on session to reserve the
         type-specific resource for a provider network segment. The
@@ -98,7 +106,7 @@ class TypeDriver(object):
         """
         pass
 
-    @abstractmethod
+    @abc.abstractmethod
     def allocate_tenant_segment(self, session):
         """Allocate resource for a new tenant network segment.
 
@@ -114,7 +122,7 @@ class TypeDriver(object):
         """
         pass
 
-    @abstractmethod
+    @abc.abstractmethod
     def release_segment(self, session, segment):
         """Release network segment.
 
@@ -129,7 +137,7 @@ class TypeDriver(object):
         pass
 
 
-@six.add_metaclass(ABCMeta)
+@six.add_metaclass(abc.ABCMeta)
 class NetworkContext(object):
     """Context passed to MechanismDrivers for changes to network resources.
 
@@ -139,33 +147,35 @@ class NetworkContext(object):
     MechanismDrivers can freely access the same information.
     """
 
-    @abstractproperty
+    @abc.abstractproperty
     def current(self):
-        """Return the current state of the network.
+        """Return the network in its current configuration.
 
-        Return the current state of the network, as defined by
-        NeutronPluginBaseV2.create_network and all extensions in the
-        ml2 plugin.
+        Return the network, as defined by NeutronPluginBaseV2.
+        create_network and all extensions in the ml2 plugin, with
+        all its properties 'current' at the time the context was
+        established.
         """
         pass
 
-    @abstractproperty
+    @abc.abstractproperty
     def original(self):
-        """Return the original state of the network.
+        """Return the network in its original configuration.
 
-        Return the original state of the network, prior to a call to
-        update_network. Method is only valid within calls to
-        update_network_precommit and update_network_postcommit.
+        Return the network, with all its properties set to their
+        original values prior to a call to update_network. Method is
+        only valid within calls to update_network_precommit and
+        update_network_postcommit.
         """
         pass
 
-    @abstractproperty
+    @abc.abstractproperty
     def network_segments(self):
         """Return the segments associated with this network resource."""
         pass
 
 
-@six.add_metaclass(ABCMeta)
+@six.add_metaclass(abc.ABCMeta)
 class SubnetContext(object):
     """Context passed to MechanismDrivers for changes to subnet resources.
 
@@ -175,28 +185,30 @@ class SubnetContext(object):
     MechanismDrivers can freely access the same information.
     """
 
-    @abstractproperty
+    @abc.abstractproperty
     def current(self):
-        """Return the current state of the subnet.
+        """Return the subnet in its current configuration.
 
-        Return the current state of the subnet, as defined by
-        NeutronPluginBaseV2.create_subnet and all extensions in the
-        ml2 plugin.
+        Return the subnet, as defined by NeutronPluginBaseV2.
+        create_subnet and all extensions in the ml2 plugin, with
+        all its properties 'current' at the time the context was
+        established.
         """
         pass
 
-    @abstractproperty
+    @abc.abstractproperty
     def original(self):
-        """Return the original state of the subnet.
+        """Return the subnet in its original configuration.
 
-        Return the original state of the subnet, prior to a call to
-        update_subnet. Method is only valid within calls to
-        update_subnet_precommit and update_subnet_postcommit.
+        Return the subnet, with all its properties set to their
+        original values prior to a call to update_subnet. Method is
+        only valid within calls to update_subnet_precommit and
+        update_subnet_postcommit.
         """
         pass
 
 
-@six.add_metaclass(ABCMeta)
+@six.add_metaclass(abc.ABCMeta)
 class PortContext(object):
     """Context passed to MechanismDrivers for changes to port resources.
 
@@ -206,37 +218,53 @@ class PortContext(object):
     freely access the same information.
     """
 
-    @abstractproperty
+    @abc.abstractproperty
     def current(self):
-        """Return the current state of the port.
+        """Return the port in its current configuration.
 
-        Return the current state of the port, as defined by
-        NeutronPluginBaseV2.create_port and all extensions in the ml2
-        plugin.
+        Return the port, as defined by NeutronPluginBaseV2.
+        create_port and all extensions in the ml2 plugin, with
+        all its properties 'current' at the time the context was
+        established.
         """
         pass
 
-    @abstractproperty
+    @abc.abstractproperty
     def original(self):
-        """Return the original state of the port.
+        """Return the port in its original configuration.
 
-        Return the original state of the port, prior to a call to
-        update_port. Method is only valid within calls to
-        update_port_precommit and update_port_postcommit.
+        Return the port, with all its properties set to their
+        original values prior to a call to update_port. Method is
+        only valid within calls to update_port_precommit and
+        update_port_postcommit.
         """
         pass
 
-    @abstractproperty
+    @abc.abstractproperty
+    def status(self):
+        """Return the status of the current port."""
+        pass
+
+    @abc.abstractproperty
+    def original_status(self):
+        """Return the status of the original port.
+
+        The method is only valid within calls to update_port_precommit and
+        update_port_postcommit.
+        """
+        pass
+
+    @abc.abstractproperty
     def network(self):
         """Return the NetworkContext associated with this port."""
         pass
 
-    @abstractproperty
+    @abc.abstractproperty
     def bound_segment(self):
         """Return the currently bound segment dictionary."""
         pass
 
-    @abstractproperty
+    @abc.abstractproperty
     def original_bound_segment(self):
         """Return the original bound segment dictionary.
 
@@ -246,12 +274,26 @@ class PortContext(object):
         """
         pass
 
-    @abstractproperty
+    @abc.abstractproperty
+    def host(self):
+        """Return the host associated with the 'current' port."""
+        pass
+
+    @abc.abstractproperty
+    def original_host(self):
+        """Return the host associated with the 'original' port.
+
+        Method is only valid within calls to update_port_precommit
+        and update_port_postcommit.
+        """
+        pass
+
+    @abc.abstractproperty
     def bound_driver(self):
         """Return the currently bound mechanism driver name."""
         pass
 
-    @abstractproperty
+    @abc.abstractproperty
     def original_bound_driver(self):
         """Return the original bound mechanism driver name.
 
@@ -261,7 +303,7 @@ class PortContext(object):
         """
         pass
 
-    @abstractmethod
+    @abc.abstractmethod
     def host_agents(self, agent_type):
         """Get agents of the specified type on port's host.
 
@@ -270,7 +312,7 @@ class PortContext(object):
         """
         pass
 
-    @abstractmethod
+    @abc.abstractmethod
     def set_binding(self, segment_id, vif_type, vif_details,
                     status=None):
         """Set the binding for the port.
@@ -286,8 +328,33 @@ class PortContext(object):
         """
         pass
 
+    @abc.abstractmethod
+    def allocate_dynamic_segment(self, segment):
+        """Allocate a dynamic segment.
 
-@six.add_metaclass(ABCMeta)
+        :param segment: A partially or fully specified segment dictionary
+
+        Called by the MechanismDriver.bind_port, create_port or update_port
+        to dynamically allocate a segment for the port using the partial
+        segment specified. The segment dictionary can be a fully or partially
+        specified segment. At a minumim it needs the network_type populated to
+        call on the appropriate type driver.
+        """
+        pass
+
+    @abc.abstractmethod
+    def release_dynamic_segment(self, segment_id):
+        """Release an allocated dynamic segment.
+
+        :param segment_id: UUID of the dynamic network segment.
+
+        Called by the MechanismDriver.delete_port or update_port to release
+        the dynamic segment allocated for this port.
+        """
+        pass
+
+
+@six.add_metaclass(abc.ABCMeta)
 class MechanismDriver(object):
     """Define stable abstract interface for ML2 mechanism drivers.
 
@@ -309,7 +376,7 @@ class MechanismDriver(object):
     methods that are part of the database transaction.
     """
 
-    @abstractmethod
+    @abc.abstractmethod
     def initialize(self):
         """Perform driver initialization.
 
@@ -589,10 +656,176 @@ class MechanismDriver(object):
 
         :param context: PortContext instance describing the port
 
-        Called inside transaction context on session, prior to
-        create_port_precommit or update_port_precommit, to
-        attempt to establish a port binding. If the driver is able to
-        bind the port, it calls context.set_binding with the binding
-        details.
+        Called outside any transaction to attempt to establish a port
+        binding using this mechanism driver. If the driver is able to
+        bind the port, it must call context.set_binding() with the
+        binding details. If the binding results are committed after
+        bind_port() returns, they will be seen by all mechanism
+        drivers as update_port_precommit() and
+        update_port_postcommit() calls.
+
+        Note that if some other thread or process concurrently binds
+        or updates the port, these binding results will not be
+        committed, and update_port_precommit() and
+        update_port_postcommit() will not be called on the mechanism
+        drivers with these results. Because binding results can be
+        discarded rather than committed, drivers should avoid making
+        persistent state changes in bind_port(), or else must ensure
+        that such state changes are eventually cleaned up.
+        """
+        pass
+
+
+@six.add_metaclass(abc.ABCMeta)
+class ExtensionDriver(object):
+    """Define stable abstract interface for ML2 extension drivers.
+
+    An extension driver extends the core resources implemented by the
+    ML2 plugin with additional attributes. Methods that process create
+    and update operations for these resources validate and persist
+    values for extended attributes supplied through the API. Other
+    methods extend the resource dictionaries returned from the API
+    operations with the values of the extended attributes.
+    """
+
+    @abc.abstractmethod
+    def initialize(self):
+        """Perform driver initialization.
+
+        Called after all drivers have been loaded and the database has
+        been initialized. No abstract methods defined below will be
+        called prior to this method being called.
+        """
+        pass
+
+    @abc.abstractproperty
+    def extension_alias(self):
+        """Supported extension alias.
+
+        Return the alias identifying the core API extension supported
+        by this driver.
+        """
+        pass
+
+    def process_create_network(self, session, data, result):
+        """Process extended attributes for create network.
+
+        :param session: database session
+        :param data: dictionary of incoming network data
+        :param result: network dictionary to extend
+
+        Called inside transaction context on session to validate and
+        persist any extended network attributes defined by this
+        driver. Extended attribute values must also be added to
+        result.
+        """
+        pass
+
+    def process_create_subnet(self, session, data, result):
+        """Process extended attributes for create subnet.
+
+        :param session: database session
+        :param data: dictionary of incoming subnet data
+        :param result: subnet dictionary to extend
+
+        Called inside transaction context on session to validate and
+        persist any extended subnet attributes defined by this
+        driver. Extended attribute values must also be added to
+        result.
+        """
+        pass
+
+    def process_create_port(self, session, data, result):
+        """Process extended attributes for create port.
+
+        :param session: database session
+        :param data: dictionary of incoming port data
+        :param result: port dictionary to extend
+
+        Called inside transaction context on session to validate and
+        persist any extended port attributes defined by this
+        driver. Extended attribute values must also be added to
+        result.
+        """
+        pass
+
+    def process_update_network(self, session, data, result):
+        """Process extended attributes for update network.
+
+        :param session: database session
+        :param data: dictionary of incoming network data
+        :param result: network dictionary to extend
+
+        Called inside transaction context on session to validate and
+        update any extended network attributes defined by this
+        driver. Extended attribute values, whether updated or not,
+        must also be added to result.
+        """
+        pass
+
+    def process_update_subnet(self, session, data, result):
+        """Process extended attributes for update subnet.
+
+        :param session: database session
+        :param data: dictionary of incoming subnet data
+        :param result: subnet dictionary to extend
+
+        Called inside transaction context on session to validate and
+        update any extended subnet attributes defined by this
+        driver. Extended attribute values, whether updated or not,
+        must also be added to result.
+        """
+        pass
+
+    def process_update_port(self, session, data, result):
+        """Process extended attributes for update port.
+
+        :param session: database session
+        :param data: dictionary of incoming port data
+        :param result: port dictionary to extend
+
+        Called inside transaction context on session to validate and
+        update any extended port attributes defined by this
+        driver. Extended attribute values, whether updated or not,
+        must also be added to result.
+        """
+        pass
+
+    def extend_network_dict(self, session, result):
+        """Add extended attributes to network dictionary.
+
+        :param session: database session
+        :param result: network dictionary to extend
+
+        Called inside transaction context on session to add any
+        extended attributes defined by this driver to a network
+        dictionary to be used for mechanism driver calls and/or
+        returned as the result of a network operation.
+        """
+        pass
+
+    def extend_subnet_dict(self, session, result):
+        """Add extended attributes to subnet dictionary.
+
+        :param session: database session
+        :param result: subnet dictionary to extend
+
+        Called inside transaction context on session to add any
+        extended attributes defined by this driver to a subnet
+        dictionary to be used for mechanism driver calls and/or
+        returned as the result of a subnet operation.
+        """
+        pass
+
+    def extend_port_dict(self, session, result):
+        """Add extended attributes to port dictionary.
+
+        :param session: database session
+        :param result: port dictionary to extend
+
+        Called inside transaction context on session to add any
+        extended attributes defined by this driver to a port
+        dictionary to be used for mechanism driver calls and/or
+        returned as the result of a port operation.
         """
         pass
