@@ -22,7 +22,6 @@ from neutron.openstack.common import importutils
 from neutron.openstack.common import log as logging
 from neutron.plugins.ml2.drivers.cisco.nexus import config as conf
 from neutron.plugins.ml2.drivers.cisco.nexus import constants as const
-from neutron.plugins.ml2.drivers.cisco.nexus import credentials_v2 as cred
 from neutron.plugins.ml2.drivers.cisco.nexus import exceptions as cexc
 from neutron.plugins.ml2.drivers.cisco.nexus import nexus_db_v2
 from neutron.plugins.ml2.drivers.cisco.nexus import nexus_snippets as snipp
@@ -35,7 +34,6 @@ class CiscoNexusDriver(object):
     def __init__(self):
         self.ncclient = None
         self.nexus_switches = conf.ML2MechCiscoConfig.nexus_dict
-        self.credentials = {}
         self.connections = {}
 
     def _import_ncclient(self):
@@ -77,20 +75,6 @@ class CiscoNexusDriver(object):
                 # the original ncclient exception.
                 raise cexc.NexusConfigFailed(config=config, exc=e)
 
-    def get_credential(self, nexus_ip):
-        """Return credential information for a given Nexus IP address.
-
-        If credential doesn't exist then also add to local dictionary.
-        """
-        if nexus_ip not in self.credentials:
-            nexus_username = cred.Store.get_username(nexus_ip)
-            nexus_password = cred.Store.get_password(nexus_ip)
-            self.credentials[nexus_ip] = {
-                const.USERNAME: nexus_username,
-                const.PASSWORD: nexus_password
-            }
-        return self.credentials[nexus_ip]
-
     def nxos_connect(self, nexus_host):
         """Make SSH connection to the Nexus Switch."""
         if getattr(self.connections.get(nexus_host), 'connected', None):
@@ -99,9 +83,8 @@ class CiscoNexusDriver(object):
         if not self.ncclient:
             self.ncclient = self._import_ncclient()
         nexus_ssh_port = int(self.nexus_switches[nexus_host, 'ssh_port'])
-        nexus_creds = self.get_credential(nexus_host)
-        nexus_user = nexus_creds[const.USERNAME]
-        nexus_password = nexus_creds[const.PASSWORD]
+        nexus_user = self.nexus_switches[nexus_host, const.USERNAME]
+        nexus_password = self.nexus_switches[nexus_host, const.PASSWORD]
         try:
             try:
                 # With new ncclient version, we can pass device_params...
@@ -164,63 +147,35 @@ class CiscoNexusDriver(object):
         confstr = self.create_xml_snippet(confstr)
         self._edit_config(nexus_host, target='running', config=confstr)
 
-    def enable_port_trunk(self, nexus_host, interface):
-        """Enable trunk mode an interface on Nexus Switch."""
-        confstr = snipp.CMD_PORT_TRUNK % (interface)
-        confstr = self.create_xml_snippet(confstr)
-        LOG.debug(_("NexusDriver: %s"), confstr)
-        self._edit_config(nexus_host, target='running', config=confstr)
-
-    def disable_switch_port(self, nexus_host, interface):
-        """Disable trunk mode an interface on Nexus Switch."""
-        confstr = snipp.CMD_NO_SWITCHPORT % (interface)
-        confstr = self.create_xml_snippet(confstr)
-        LOG.debug(_("NexusDriver: %s"), confstr)
-        self._edit_config(nexus_host, target='running', config=confstr)
-
-    def enable_vlan_on_trunk_int(self, nexus_host, vlanid, interface):
+    def enable_vlan_on_trunk_int(self, nexus_host, vlanid, intf_type,
+                                 interface):
         """Enable a VLAN on a trunk interface."""
         # If more than one VLAN is configured on this interface then
         # include the 'add' keyword.
-        if len(nexus_db_v2.get_port_switch_bindings(interface,
-                                                    nexus_host)) == 1:
+        if len(nexus_db_v2.get_port_switch_bindings(
+                '%s:%s' % (intf_type, interface), nexus_host)) == 1:
             snippet = snipp.CMD_INT_VLAN_SNIPPET
         else:
             snippet = snipp.CMD_INT_VLAN_ADD_SNIPPET
-        confstr = snippet % (interface, vlanid)
+        confstr = snippet % (intf_type, interface, vlanid, intf_type)
         confstr = self.create_xml_snippet(confstr)
         LOG.debug(_("NexusDriver: %s"), confstr)
         self._edit_config(nexus_host, target='running', config=confstr)
 
-    def disable_vlan_on_trunk_int(self, nexus_host, vlanid, interface):
+    def disable_vlan_on_trunk_int(self, nexus_host, vlanid, intf_type,
+                                  interface):
         """Disable a VLAN on a trunk interface."""
-        confstr = snipp.CMD_NO_VLAN_INT_SNIPPET % (interface, vlanid)
+        confstr = (snipp.CMD_NO_VLAN_INT_SNIPPET %
+                   (intf_type, interface, vlanid, intf_type))
         confstr = self.create_xml_snippet(confstr)
         LOG.debug(_("NexusDriver: %s"), confstr)
         self._edit_config(nexus_host, target='running', config=confstr)
 
     def create_and_trunk_vlan(self, nexus_host, vlan_id, vlan_name,
-                              nexus_port):
+                              intf_type, nexus_port):
         """Create VLAN and trunk it on the specified ports."""
         self.create_vlan(nexus_host, vlan_id, vlan_name)
         LOG.debug(_("NexusDriver created VLAN: %s"), vlan_id)
         if nexus_port:
-            self.enable_vlan_on_trunk_int(nexus_host, vlan_id, nexus_port)
-
-    def delete_and_untrunk_vlan(self, nexus_host, vlan_id, nexus_port):
-        """Delete VLAN and untrunk it from the specified ports."""
-        self.delete_vlan(nexus_host, vlan_id)
-        if nexus_port:
-            self.disable_vlan_on_trunk_int(nexus_host, vlan_id, nexus_port)
-
-    def create_vlan_svi(self, nexus_host, vlan_id, gateway_ip):
-        confstr = snipp.CMD_VLAN_SVI_SNIPPET % (vlan_id, gateway_ip)
-        confstr = self.create_xml_snippet(confstr)
-        LOG.debug(_("NexusDriver: %s"), confstr)
-        self._edit_config(nexus_host, target='running', config=confstr)
-
-    def delete_vlan_svi(self, nexus_host, vlan_id):
-        confstr = snipp.CMD_NO_VLAN_SVI_SNIPPET % vlan_id
-        confstr = self.create_xml_snippet(confstr)
-        LOG.debug(_("NexusDriver: %s"), confstr)
-        self._edit_config(nexus_host, target='running', config=confstr)
+            self.enable_vlan_on_trunk_int(nexus_host, vlan_id, intf_type,
+                                          nexus_port)
