@@ -13,6 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import random
+
 from oslo.db import exception as db_exc
 
 from neutron.common import exceptions as exc
@@ -20,9 +22,7 @@ from neutron.openstack.common import log
 from neutron.plugins.ml2 import driver_api as api
 
 
-# Number of retries to find a valid segment candidate and allocate it
-DB_MAX_RETRIES = 10
-
+IDPOOL_SELECT_SIZE = 100
 
 LOG = log.getLogger(__name__)
 
@@ -107,37 +107,33 @@ class TypeDriverHelper(api.TypeDriver):
                       filter_by(allocated=False, **filters))
 
             # Selected segment can be allocated before update by someone else,
-            # We retry until update success or DB_MAX_RETRIES retries
-            for attempt in range(1, DB_MAX_RETRIES + 1):
-                alloc = select.first()
+            allocs = select.limit(IDPOOL_SELECT_SIZE).all()
 
-                if not alloc:
-                    # No resource available
-                    return
+            if not allocs:
+                # No resource available
+                return
 
-                raw_segment = dict((k, alloc[k]) for k in self.primary_keys)
-                LOG.debug("%(type)s segment allocate from pool, attempt "
-                          "%(attempt)s started with %(segment)s ",
-                          {"type": network_type, "attempt": attempt,
+            alloc = random.choice(allocs)
+            raw_segment = dict((k, alloc[k]) for k in self.primary_keys)
+            LOG.debug("%(type)s segment allocate from pool "
+                      "started with %(segment)s ",
+                      {"type": network_type,
+                       "segment": raw_segment})
+            count = (session.query(self.model).
+                     filter_by(allocated=False, **raw_segment).
+                     update({"allocated": True}))
+            if count:
+                LOG.debug("%(type)s segment allocate from pool "
+                          "success with %(segment)s ",
+                          {"type": network_type,
                            "segment": raw_segment})
-                count = (session.query(self.model).
-                         filter_by(allocated=False, **raw_segment).
-                         update({"allocated": True}))
-                if count:
-                    LOG.debug("%(type)s segment allocate from pool, attempt "
-                              "%(attempt)s success with %(segment)s ",
-                              {"type": network_type, "attempt": attempt,
-                               "segment": raw_segment})
-                    return alloc
+                return alloc
 
-                # Segment allocated since select
-                LOG.debug("Allocate %(type)s segment from pool, "
-                          "attempt %(attempt)s failed with segment "
-                          "%(segment)s",
-                          {"type": network_type, "attempt": attempt,
-                           "segment": raw_segment})
-
-        LOG.warning(_("Allocate %(type)s segment from pool failed "
-                      "after %(number)s failed attempts"),
-                    {"type": network_type, "number": DB_MAX_RETRIES})
-        raise exc.NoNetworkFoundInMaximumAllowedAttempts()
+            # Segment allocated since select
+            LOG.debug("Allocate %(type)s segment from pool "
+                      "failed with segment %(segment)s",
+                      {"type": network_type,
+                       "segment": raw_segment})
+            # saving real exception in case we exceeded amount of attempts
+            raise exc.RetryRequest(
+                exc.NoNetworkFoundInMaximumAllowedAttempts())
