@@ -484,7 +484,7 @@ class Ml2Plugin(db_base_plugin_v2.NeutronDbPluginV2,
 
     # TODO(apech): Need to override bulk operations
 
-    def create_network(self, context, network):
+    def _create_network_db(self, context, network):
         net_data = network['network']
         tenant_id = self._get_tenant_id_for_create(context, net_data)
         session = context.session
@@ -501,7 +501,16 @@ class Ml2Plugin(db_base_plugin_v2.NeutronDbPluginV2,
             mech_context = driver_context.NetworkContext(self, context,
                                                          result)
             self.mechanism_manager.create_network_precommit(mech_context)
+        return result, mech_context
 
+    @db_api.wrap_db_retry(max_retries=db_api.MAX_RETRIES,
+                          retry_on_request=True)
+    def _create_network_with_retries(self, context, network):
+        return self._create_network_db(context, network)
+
+    def create_network(self, context, network):
+        result, mech_context = self._create_network_with_retries(context,
+                                                                 network)
         try:
             self.mechanism_manager.create_network_postcommit(mech_context)
         except ml2_exc.MechanismDriverError:
@@ -598,11 +607,6 @@ class Ml2Plugin(db_base_plugin_v2.NeutronDbPluginV2,
         session = context.session
         while True:
             try:
-                # REVISIT(rkukura): Its not clear that
-                # with_lockmode('update') is really needed in this
-                # transaction, and if not, the semaphore can also be
-                # removed.
-                #
                 # REVISIT: Serialize this operation with a semaphore
                 # to prevent deadlock waiting to acquire a DB lock
                 # held by another thread in the same process, leading
@@ -614,13 +618,14 @@ class Ml2Plugin(db_base_plugin_v2.NeutronDbPluginV2,
                 # Additionally, a rollback may not be enough to undo the
                 # deletion of a floating IP with certain L3 backends.
                 self._process_l3_delete(context, id)
+                # Using query().with_lockmode isn't necessary. Foreign-key
+                # constraints prevent deletion if concurrent creation happens.
                 with contextlib.nested(lockutils.lock('db-access'),
                                        session.begin(subtransactions=True)):
                     # Get ports to auto-delete.
                     ports = (session.query(models_v2.Port).
                              enable_eagerloads(False).
-                             filter_by(network_id=id).
-                             with_lockmode('update').all())
+                             filter_by(network_id=id).all())
                     LOG.debug(_("Ports to auto-delete: %s"), ports)
                     only_auto_del = all(p.device_owner
                                         in db_base_plugin_v2.
@@ -633,8 +638,7 @@ class Ml2Plugin(db_base_plugin_v2.NeutronDbPluginV2,
                     # Get subnets to auto-delete.
                     subnets = (session.query(models_v2.Subnet).
                                enable_eagerloads(False).
-                               filter_by(network_id=id).
-                               with_lockmode('update').all())
+                               filter_by(network_id=id).all())
                     LOG.debug(_("Subnets to auto-delete: %s"), subnets)
 
                     if not (ports or subnets):
@@ -729,22 +733,33 @@ class Ml2Plugin(db_base_plugin_v2.NeutronDbPluginV2,
                                    session.begin(subtransactions=True)):
                 record = self._get_subnet(context, id)
                 subnet = self._make_subnet_dict(record, None)
-                # Get ports to auto-deallocate
-                allocated = (session.query(models_v2.IPAllocation).
-                             filter_by(subnet_id=id).
-                             join(models_v2.Port).
-                             filter_by(network_id=subnet['network_id']).
-                             with_lockmode('update').all())
+                qry_allocated = (session.query(models_v2.IPAllocation).
+                                 filter_by(subnet_id=id).
+                                 join(models_v2.Port))
+                is_auto_addr_subnet = ipv6_utils.is_auto_address_subnet(subnet)
+                # Remove network owned ports, and delete IP allocations
+                # for IPv6 addresses which were automatically generated
+                # via SLAAC
+                if not is_auto_addr_subnet:
+                    qry_allocated = (
+                        qry_allocated.filter(models_v2.Port.device_owner.
+                        in_(db_base_plugin_v2.AUTO_DELETE_PORT_OWNERS)))
+                allocated = qry_allocated.all()
+                # Delete all the IPAllocation that can be auto-deleted
+                if allocated:
+                    map(session.delete, allocated)
                 LOG.debug(_("Ports to auto-deallocate: %s"), allocated)
-                only_auto_del = (
-                    ipv6_utils.is_auto_address_subnet(subnet) or
-                    all(not a.port_id or
-                        a.ports.device_owner in db_base_plugin_v2.
-                        AUTO_DELETE_PORT_OWNERS for a in allocated))
-                if not only_auto_del:
+                # Check if there are tenant owned ports
+                tenant_port = (session.query(models_v2.IPAllocation).
+                               filter_by(subnet_id=id).
+                               join(models_v2.Port).
+                               first())
+                if tenant_port:
                     LOG.debug(_("Tenant-owned ports exist"))
                     raise exc.SubnetInUse(subnet_id=id)
 
+                # If allocated is None, then all the IPAllocation were
+                # correctly deleted during the previous pass.
                 if not allocated:
                     mech_context = driver_context.SubnetContext(self, context,
                                                                 subnet)
@@ -772,7 +787,6 @@ class Ml2Plugin(db_base_plugin_v2.NeutronDbPluginV2,
                         with excutils.save_and_reraise_exception():
                             LOG.exception(_("Exception deleting fixed_ip from "
                                             "port %s"), a.port_id)
-                session.delete(a)
 
         try:
             self.mechanism_manager.delete_subnet_postcommit(mech_context)
@@ -977,6 +991,8 @@ class Ml2Plugin(db_base_plugin_v2.NeutronDbPluginV2,
                 cur_binding.driver = new_binding.driver
                 cur_binding.segment = new_binding.segment
 
+    @db_api.wrap_db_retry(max_retries=db_api.MAX_RETRIES,
+                          retry_on_deadlock=True)
     def delete_port(self, context, id, l3_port_check=True):
         LOG.debug(_("Deleting port %s"), id)
         removed_routers = []
