@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-#
 # Copyright 2012 NEC Corporation.  All rights reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -13,15 +11,12 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-# @author: Ryota MIBU
-# @author: Akihiro MOTOKI
-
-from abc import ABCMeta, abstractmethod
 
+import abc
 import six
 
 
-@six.add_metaclass(ABCMeta)
+@six.add_metaclass(abc.ABCMeta)
 class OFCDriverBase(object):
     """OpenFlow Controller (OFC) Driver Specification.
 
@@ -29,7 +24,7 @@ class OFCDriverBase(object):
     It would be better that other methods like update_* are implemented.
     """
 
-    @abstractmethod
+    @abc.abstractmethod
     def create_tenant(self, description, tenant_id=None):
         """Create a new tenant at OpenFlow Controller.
 
@@ -41,7 +36,7 @@ class OFCDriverBase(object):
         """
         pass
 
-    @abstractmethod
+    @abc.abstractmethod
     def delete_tenant(self, ofc_tenant_id):
         """Delete a tenant at OpenFlow Controller.
 
@@ -49,7 +44,7 @@ class OFCDriverBase(object):
         """
         pass
 
-    @abstractmethod
+    @abc.abstractmethod
     def create_network(self, ofc_tenant_id, description, network_id=None):
         """Create a new network on specified OFC tenant at OpenFlow Controller.
 
@@ -64,7 +59,7 @@ class OFCDriverBase(object):
         """
         pass
 
-    @abstractmethod
+    @abc.abstractmethod
     def delete_network(self, ofc_network_id):
         """Delete a netwrok at OpenFlow Controller.
 
@@ -72,7 +67,7 @@ class OFCDriverBase(object):
         """
         pass
 
-    @abstractmethod
+    @abc.abstractmethod
     def create_port(self, ofc_network_id, portinfo,
                     port_id=None, filters=None):
         """Create a new port on specified network at OFC.
@@ -97,7 +92,7 @@ class OFCDriverBase(object):
         """
         pass
 
-    @abstractmethod
+    @abc.abstractmethod
     def delete_port(self, ofc_port_id):
         """Delete a port at OpenFlow Controller.
 
