@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-#
 # Copyright 2013 Dell Inc.
 # All Rights Reserved.
 #
@@ -14,8 +12,6 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
-# @author: Rajesh Mohan, Rajesh_Mohan3@Dell.com, DELL Inc.
 
 from neutron.agent.linux import iptables_manager
 from neutron.extensions import firewall as fw_ext
@@ -24,7 +20,6 @@ from neutron.services.firewall.drivers import fwaas_base
 
 LOG = logging.getLogger(__name__)
 FWAAS_DRIVER_NAME = 'Fwaas iptables driver'
-FWAAS_CHAIN = 'fwaas'
 FWAAS_DEFAULT_CHAIN = 'fwaas-default-policy'
 INGRESS_DIRECTION = 'ingress'
 EGRESS_DIRECTION = 'egress'
@@ -42,6 +37,10 @@ IPV6 = 'ipv6'
 IP_VER_TAG = {IPV4: 'v4',
               IPV6: 'v6'}
 
+INTERNAL_DEV_PREFIX = 'qr-'
+SNAT_INT_DEV_PREFIX = 'sg-'
+ROUTER_2_FIP_DEV_PREFIX = 'rfp-'
+
 
 class IptablesFwaasDriver(fwaas_base.FwaasDriverBase):
     """IPTables driver for Firewall As A Service."""
@@ -49,99 +48,132 @@ class IptablesFwaasDriver(fwaas_base.FwaasDriverBase):
     def __init__(self):
         LOG.debug(_("Initializing fwaas iptables driver"))
 
-    def create_firewall(self, apply_list, firewall):
+    def create_firewall(self, agent_mode, apply_list, firewall):
         LOG.debug(_('Creating firewall %(fw_id)s for tenant %(tid)s)'),
                   {'fw_id': firewall['id'], 'tid': firewall['tenant_id']})
         try:
             if firewall['admin_state_up']:
-                self._setup_firewall(apply_list, firewall)
+                self._setup_firewall(agent_mode, apply_list, firewall)
             else:
-                self.apply_default_policy(apply_list, firewall)
+                self.apply_default_policy(agent_mode, apply_list, firewall)
         except (LookupError, RuntimeError):
             # catch known library exceptions and raise Fwaas generic exception
             LOG.exception(_("Failed to create firewall: %s"), firewall['id'])
             raise fw_ext.FirewallInternalDriverError(driver=FWAAS_DRIVER_NAME)
 
-    def delete_firewall(self, apply_list, firewall):
+    def _get_ipt_mgrs_with_if_prefix(self, agent_mode, router_info):
+        """Gets the iptables manager along with the if prefix to apply rules.
+
+        With DVR we can have differing namespaces depending on which agent
+        (on Network or Compute node). Also, there is an associated i/f for
+        each namespace. The iptables on the relevant namespace and matching
+        i/f are provided. On the Network node we could have both the snat
+        namespace and a fip so this is provided back as a list - so in that
+        scenario rules can be applied on both.
+        """
+        if not router_info.router['distributed']:
+            return [{'ipt': router_info.iptables_manager,
+                     'if_prefix': INTERNAL_DEV_PREFIX}]
+        ipt_mgrs = []
+        # TODO(sridar): refactor to get strings to a common location.
+        if agent_mode == 'dvr_snat':
+            if router_info.snat_iptables_manager:
+                ipt_mgrs.append({'ipt': router_info.snat_iptables_manager,
+                                 'if_prefix': SNAT_INT_DEV_PREFIX})
+        if router_info.dist_fip_count:
+            # handle the fip case on n/w or compute node.
+            ipt_mgrs.append({'ipt': router_info.iptables_manager,
+                             'if_prefix': ROUTER_2_FIP_DEV_PREFIX})
+        return ipt_mgrs
+
+    def delete_firewall(self, agent_mode, apply_list, firewall):
         LOG.debug(_('Deleting firewall %(fw_id)s for tenant %(tid)s)'),
                   {'fw_id': firewall['id'], 'tid': firewall['tenant_id']})
         fwid = firewall['id']
         try:
             for router_info in apply_list:
-                ipt_mgr = router_info.iptables_manager
-                self._remove_chains(fwid, ipt_mgr)
-                self._remove_default_chains(ipt_mgr)
-                # apply the changes immediately (no defer in firewall path)
-                ipt_mgr.defer_apply_off()
+                ipt_if_prefix_list = self._get_ipt_mgrs_with_if_prefix(
+                    agent_mode, router_info)
+                for ipt_if_prefix in ipt_if_prefix_list:
+                    ipt_mgr = ipt_if_prefix['ipt']
+                    self._remove_chains(fwid, ipt_mgr)
+                    self._remove_default_chains(ipt_mgr)
+                    # apply the changes immediately (no defer in firewall path)
+                    ipt_mgr.defer_apply_off()
         except (LookupError, RuntimeError):
             # catch known library exceptions and raise Fwaas generic exception
             LOG.exception(_("Failed to delete firewall: %s"), fwid)
             raise fw_ext.FirewallInternalDriverError(driver=FWAAS_DRIVER_NAME)
 
-    def update_firewall(self, apply_list, firewall):
+    def update_firewall(self, agent_mode, apply_list, firewall):
         LOG.debug(_('Updating firewall %(fw_id)s for tenant %(tid)s)'),
                   {'fw_id': firewall['id'], 'tid': firewall['tenant_id']})
         try:
             if firewall['admin_state_up']:
-                self._setup_firewall(apply_list, firewall)
+                self._setup_firewall(agent_mode, apply_list, firewall)
             else:
-                self.apply_default_policy(apply_list, firewall)
+                self.apply_default_policy(agent_mode, apply_list, firewall)
         except (LookupError, RuntimeError):
             # catch known library exceptions and raise Fwaas generic exception
             LOG.exception(_("Failed to update firewall: %s"), firewall['id'])
             raise fw_ext.FirewallInternalDriverError(driver=FWAAS_DRIVER_NAME)
 
-    def apply_default_policy(self, apply_list, firewall):
+    def apply_default_policy(self, agent_mode, apply_list, firewall):
         LOG.debug(_('Applying firewall %(fw_id)s for tenant %(tid)s)'),
                   {'fw_id': firewall['id'], 'tid': firewall['tenant_id']})
         fwid = firewall['id']
         try:
             for router_info in apply_list:
-                ipt_mgr = router_info.iptables_manager
+                ipt_if_prefix_list = self._get_ipt_mgrs_with_if_prefix(
+                    agent_mode, router_info)
+                for ipt_if_prefix in ipt_if_prefix_list:
+                    # the following only updates local memory; no hole in FW
+                    ipt_mgr = ipt_if_prefix['ipt']
+                    self._remove_chains(fwid, ipt_mgr)
+                    self._remove_default_chains(ipt_mgr)
 
-                # the following only updates local memory; no hole in FW
-                self._remove_chains(fwid, ipt_mgr)
-                self._remove_default_chains(ipt_mgr)
+                    # create default 'DROP ALL' policy chain
+                    self._add_default_policy_chain_v4v6(ipt_mgr)
+                    self._enable_policy_chain(fwid, ipt_if_prefix)
 
-                # create default 'DROP ALL' policy chain
-                self._add_default_policy_chain_v4v6(ipt_mgr)
-                self._enable_policy_chain(fwid, ipt_mgr)
-
-                # apply the changes immediately (no defer in firewall path)
-                ipt_mgr.defer_apply_off()
+                    # apply the changes immediately (no defer in firewall path)
+                    ipt_mgr.defer_apply_off()
         except (LookupError, RuntimeError):
             # catch known library exceptions and raise Fwaas generic exception
             LOG.exception(_("Failed to apply default policy on firewall: %s"),
                           fwid)
             raise fw_ext.FirewallInternalDriverError(driver=FWAAS_DRIVER_NAME)
 
-    def _setup_firewall(self, apply_list, firewall):
+    def _setup_firewall(self, agent_mode, apply_list, firewall):
         fwid = firewall['id']
         for router_info in apply_list:
-            ipt_mgr = router_info.iptables_manager
+            ipt_if_prefix_list = self._get_ipt_mgrs_with_if_prefix(
+                agent_mode, router_info)
+            for ipt_if_prefix in ipt_if_prefix_list:
+                ipt_mgr = ipt_if_prefix['ipt']
+                # the following only updates local memory; no hole in FW
+                self._remove_chains(fwid, ipt_mgr)
+                self._remove_default_chains(ipt_mgr)
 
-            # the following only updates local memory; no hole in FW
-            self._remove_chains(fwid, ipt_mgr)
-            self._remove_default_chains(ipt_mgr)
+                # create default 'DROP ALL' policy chain
+                self._add_default_policy_chain_v4v6(ipt_mgr)
+                #create chain based on configured policy
+                self._setup_chains(firewall, ipt_if_prefix)
 
-            # create default 'DROP ALL' policy chain
-            self._add_default_policy_chain_v4v6(ipt_mgr)
-            #create chain based on configured policy
-            self._setup_chains(firewall, ipt_mgr)
-
-            # apply the changes immediately (no defer in firewall path)
-            ipt_mgr.defer_apply_off()
+                # apply the changes immediately (no defer in firewall path)
+                ipt_mgr.defer_apply_off()
 
     def _get_chain_name(self, fwid, ver, direction):
         return '%s%s%s' % (CHAIN_NAME_PREFIX[direction],
                            IP_VER_TAG[ver],
                            fwid)
 
-    def _setup_chains(self, firewall, ipt_mgr):
+    def _setup_chains(self, firewall, ipt_if_prefix):
         """Create Fwaas chain using the rules in the policy
         """
         fw_rules_list = firewall['firewall_rule_list']
         fwid = firewall['id']
+        ipt_mgr = ipt_if_prefix['ipt']
 
         #default rules for invalid packets and established sessions
         invalid_rule = self._drop_invalid_packets_rule()
@@ -173,7 +205,7 @@ class IptablesFwaasDriver(fwaas_base.FwaasDriverBase):
             ochain_name = self._get_chain_name(fwid, ver, EGRESS_DIRECTION)
             table.add_rule(ichain_name, iptbl_rule)
             table.add_rule(ochain_name, iptbl_rule)
-        self._enable_policy_chain(fwid, ipt_mgr)
+        self._enable_policy_chain(fwid, ipt_if_prefix)
 
     def _remove_default_chains(self, nsid):
         """Remove fwaas default policy chain."""
@@ -207,8 +239,10 @@ class IptablesFwaasDriver(fwaas_base.FwaasDriverBase):
         for rule in rules:
             table.add_rule(chain_name, rule)
 
-    def _enable_policy_chain(self, fwid, ipt_mgr):
+    def _enable_policy_chain(self, fwid, ipt_if_prefix):
         bname = iptables_manager.binary_name
+        ipt_mgr = ipt_if_prefix['ipt']
+        if_prefix = ipt_if_prefix['if_prefix']
 
         for (ver, tbl) in [(IPV4, ipt_mgr.ipv4['filter']),
                            (IPV6, ipt_mgr.ipv6['filter'])]:
@@ -216,20 +250,20 @@ class IptablesFwaasDriver(fwaas_base.FwaasDriverBase):
                 chain_name = self._get_chain_name(fwid, ver, direction)
                 chain_name = iptables_manager.get_chain_name(chain_name)
                 if chain_name in tbl.chains:
-                    jump_rule = ['%s qr-+ -j %s-%s' % (IPTABLES_DIR[direction],
-                                                       bname, chain_name)]
-                    self._add_rules_to_chain(ipt_mgr, ver, 'FORWARD',
-                                             jump_rule)
+                    jump_rule = ['%s %s+ -j %s-%s' % (IPTABLES_DIR[direction],
+                        if_prefix, bname, chain_name)]
+                    self._add_rules_to_chain(ipt_mgr,
+                        ver, 'FORWARD', jump_rule)
 
         #jump to DROP_ALL policy
         chain_name = iptables_manager.get_chain_name(FWAAS_DEFAULT_CHAIN)
-        jump_rule = ['-o qr-+ -j %s-%s' % (bname, chain_name)]
+        jump_rule = ['-o %s+ -j %s-%s' % (if_prefix, bname, chain_name)]
         self._add_rules_to_chain(ipt_mgr, IPV4, 'FORWARD', jump_rule)
         self._add_rules_to_chain(ipt_mgr, IPV6, 'FORWARD', jump_rule)
 
         #jump to DROP_ALL policy
         chain_name = iptables_manager.get_chain_name(FWAAS_DEFAULT_CHAIN)
-        jump_rule = ['-i qr-+ -j %s-%s' % (bname, chain_name)]
+        jump_rule = ['-i %s+ -j %s-%s' % (if_prefix, bname, chain_name)]
         self._add_rules_to_chain(ipt_mgr, IPV4, 'FORWARD', jump_rule)
         self._add_rules_to_chain(ipt_mgr, IPV6, 'FORWARD', jump_rule)
 
