@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-#
 # Copyright 2013 New Dream Network, LLC (DreamHost)
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -13,8 +11,6 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
-# @author: Mark McClain, DreamHost
 
 import uuid
 
@@ -22,7 +18,7 @@ from oslo.config import cfg
 
 from neutron.common import constants as q_const
 from neutron.common import exceptions as n_exc
-from neutron.common import rpc as q_rpc
+from neutron.common import rpc as n_rpc
 from neutron.common import topics
 from neutron.db import agents_db
 from neutron.db.loadbalancer import loadbalancer_db
@@ -30,8 +26,6 @@ from neutron.extensions import lbaas_agentscheduler
 from neutron.extensions import portbindings
 from neutron.openstack.common import importutils
 from neutron.openstack.common import log as logging
-from neutron.openstack.common import rpc
-from neutron.openstack.common.rpc import proxy
 from neutron.plugins.common import constants
 from neutron.services.loadbalancer.drivers import abstract_driver
 
@@ -53,7 +47,7 @@ class DriverNotSpecified(n_exc.NeutronException):
                 "in plugin driver.")
 
 
-class LoadBalancerCallbacks(object):
+class LoadBalancerCallbacks(n_rpc.RpcCallback):
 
     RPC_API_VERSION = '2.0'
     # history
@@ -63,12 +57,9 @@ class LoadBalancerCallbacks(object):
     #       - pool_deployed() and update_status() methods added;
 
     def __init__(self, plugin):
+        super(LoadBalancerCallbacks, self).__init__()
         self.plugin = plugin
 
-    def create_rpc_dispatcher(self):
-        return q_rpc.PluginRpcDispatcher(
-            [self, agents_db.AgentExtRpcCallback(self.plugin)])
-
     def get_ready_devices(self, context, host=None):
         with context.session.begin(subtransactions=True):
             agents = self.plugin.get_lbaas_agents(context,
@@ -239,7 +230,7 @@ class LoadBalancerCallbacks(object):
         self.plugin.update_pool_stats(context, pool_id, data=stats)
 
 
-class LoadBalancerAgentApi(proxy.RpcProxy):
+class LoadBalancerAgentApi(n_rpc.RpcProxy):
     """Plugin side of plugin to agent RPC API."""
 
     BASE_RPC_API_VERSION = '2.0'
@@ -344,13 +335,16 @@ class AgentDriverBase(abstract_driver.LoadBalancerAbstractDriver):
         if hasattr(self.plugin, 'agent_callbacks'):
             return
 
-        self.plugin.agent_callbacks = LoadBalancerCallbacks(self.plugin)
-        self.plugin.conn = rpc.create_connection(new=True)
+        self.plugin.agent_endpoints = [
+            LoadBalancerCallbacks(self.plugin),
+            agents_db.AgentExtRpcCallback(self.plugin)
+        ]
+        self.plugin.conn = n_rpc.create_connection(new=True)
         self.plugin.conn.create_consumer(
             topics.LOADBALANCER_PLUGIN,
-            self.plugin.agent_callbacks.create_rpc_dispatcher(),
+            self.plugin.agent_endpoints,
             fanout=False)
-        self.plugin.conn.consume_in_thread()
+        self.plugin.conn.consume_in_threads()
 
     def get_pool_agent(self, context, pool_id):
         agent = self.plugin.get_lbaas_agent_hosting_pool(context, pool_id)
