@@ -12,10 +12,8 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
-# @author:  Ivar Lazzaro, Embrane, Inc. ivar@embrane.com
 
-from functools import wraps
+import functools
 
 from heleosapi import exceptions as h_exc
 
@@ -34,7 +32,7 @@ def handler(event, handler):
         else:
             handler[event].append(f)
 
-        @wraps(f)
+        @functools.wraps(f)
         def wrapped_f(*args, **kwargs):
             return f(*args, **kwargs)
 
