@@ -12,13 +12,10 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
-# @author: Avishay Balderman, Radware
 
 from neutron.api.v2 import attributes as attrs
 from neutron.common import exceptions as n_exc
 from neutron import context
-from neutron.db import api as qdbapi
 from neutron.db.loadbalancer import loadbalancer_db as ldb
 from neutron.db import servicetype_db as st_db
 from neutron.extensions import loadbalancer
@@ -52,7 +49,6 @@ class LoadBalancerPlugin(ldb.LoadBalancerPluginDb,
     def __init__(self):
         """Initialization for the loadbalancer service plugin."""
 
-        qdbapi.register_models()
         self.service_type_manager = st_db.ServiceTypeManager.get_instance()
         self._load_drivers()
 
@@ -82,7 +78,7 @@ class LoadBalancerPlugin(ldb.LoadBalancerPluginDb,
             msg = _("Delete associated loadbalancer pools before "
                     "removing providers %s") % list(lost_providers)
             LOG.exception(msg)
-            raise SystemExit(msg)
+            raise SystemExit(1)
 
     def _get_driver_for_provider(self, provider):
         if provider in self.drivers:
@@ -230,7 +226,14 @@ class LoadBalancerPlugin(ldb.LoadBalancerPluginDb,
         driver = self._get_driver_for_pool(context, m['pool_id'])
         driver.delete_member(context, m)
 
+    def _validate_hm_parameters(self, delay, timeout):
+        if delay < timeout:
+            raise loadbalancer.DelayOrTimeoutInvalid()
+
     def create_health_monitor(self, context, health_monitor):
+        new_hm = health_monitor['health_monitor']
+        self._validate_hm_parameters(new_hm['delay'], new_hm['timeout'])
+
         hm = super(LoadBalancerPlugin, self).create_health_monitor(
             context,
             health_monitor
@@ -238,7 +241,12 @@ class LoadBalancerPlugin(ldb.LoadBalancerPluginDb,
         return hm
 
     def update_health_monitor(self, context, id, health_monitor):
+        new_hm = health_monitor['health_monitor']
         old_hm = self.get_health_monitor(context, id)
+        delay = new_hm.get('delay', old_hm.get('delay'))
+        timeout = new_hm.get('timeout', old_hm.get('timeout'))
+        self._validate_hm_parameters(delay, timeout)
+
         hm = super(LoadBalancerPlugin, self).update_health_monitor(
             context,
             id,
