@@ -136,6 +136,8 @@ vrrp_instance VR_1 {
     interface eth0
     virtual_router_id 1
     priority 50
+    garp_master_repeat 5
+    garp_master_refresh 10
     advert_int 5
     authentication {
         auth_type AH
@@ -162,6 +164,8 @@ vrrp_instance VR_2 {
     interface eth4
     virtual_router_id 2
     priority 50
+    garp_master_repeat 5
+    garp_master_refresh 10
     mcast_src_ip 224.0.0.1
     track_interface {
         eth4
@@ -246,6 +250,8 @@ vrrp_instance VR_1 {
     interface eth0
     virtual_router_id 1
     priority 50
+    garp_master_repeat 5
+    garp_master_refresh 10
     advert_int 5
     authentication {
         auth_type AH
@@ -269,6 +275,8 @@ vrrp_instance VR_2 {
     interface eth4
     virtual_router_id 2
     priority 50
+    garp_master_repeat 5
+    garp_master_refresh 10
     mcast_src_ip 224.0.0.1
     track_interface {
         eth4
@@ -291,6 +299,8 @@ vrrp_instance VR_2 {
     interface eth0
     virtual_router_id 1
     priority 50
+    garp_master_repeat 5
+    garp_master_refresh 10
     virtual_ipaddress {
         169.254.0.1/24 dev eth0
     }
@@ -300,6 +310,15 @@ vrrp_instance VR_2 {
         self.assertEqual(expected, '\n'.join(instance.build_config()))
 
 
+class KeepalivedVipAddressTestCase(base.BaseTestCase):
+    def test_vip_with_scope(self):
+        vip = keepalived.KeepalivedVipAddress('fe80::3e97:eff:fe26:3bfa/64',
+                                              'eth1',
+                                              'link')
+        self.assertEqual('fe80::3e97:eff:fe26:3bfa/64 dev eth1 scope link',
+                         vip.build_config())
+
+
 class KeepalivedVirtualRouteTestCase(base.BaseTestCase):
     def test_virtual_route_with_dev(self):
         route = keepalived.KeepalivedVirtualRoute('0.0.0.0/0', '1.2.3.4',
