@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Big Switch Networks, Inc.  All rights reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -15,21 +13,19 @@
 #    under the License.
 #
 # Adapted from neutron.tests.unit.test_l3_plugin
-# @author: Sumit Naiksatam, sumitnaiksatam@gmail.com
-#
 
 import contextlib
 import copy
 
-from mock import patch
+import mock
 from oslo.config import cfg
-from six.moves import xrange
+from six import moves
 from webob import exc
 
-from neutron.common.test_lib import test_config
+from neutron.common import test_lib
 from neutron import context
 from neutron.extensions import l3
-from neutron.manager import NeutronManager
+from neutron import manager
 from neutron.openstack.common import uuidutils
 from neutron.plugins.bigswitch.extensions import routerrule
 from neutron.tests.unit.bigswitch import fake_server
@@ -39,6 +35,7 @@ from neutron.tests.unit import test_extension_extradhcpopts as test_extradhcp
 from neutron.tests.unit import test_l3_plugin
 
 
+HTTPCON = 'neutron.plugins.bigswitch.servermanager.httplib.HTTPConnection'
 _uuid = uuidutils.generate_uuid
 
 
@@ -64,29 +61,43 @@ class DHCPOptsTestCase(test_base.BigSwitchTestBase,
         self.setup_config_files()
         super(test_extradhcp.ExtraDhcpOptDBTestCase,
               self).setUp(plugin=self._plugin_name)
+        self.setup_db()
+        self.startHttpPatch()
 
 
-class RouterDBTestCase(test_base.BigSwitchTestBase,
-                       test_l3_plugin.L3NatDBIntTestCase):
+class RouterDBTestBase(test_base.BigSwitchTestBase,
+                       test_l3_plugin.L3BaseForIntTests,
+                       test_l3_plugin.L3NatTestCaseMixin):
+
+    mock_rescheduling = False
 
     def setUp(self):
         self.setup_patches()
         self.setup_config_files()
         ext_mgr = RouterRulesTestExtensionManager()
-        super(RouterDBTestCase, self).setUp(plugin=self._plugin_name,
-                                            ext_mgr=ext_mgr)
+        service_plugins = {'L3_ROUTER_NAT': self._l3_plugin_name}
+        super(RouterDBTestBase, self).setUp(plugin=self._plugin_name,
+                                            ext_mgr=ext_mgr,
+                                            service_plugins=service_plugins)
+        self.setup_db()
         cfg.CONF.set_default('allow_overlapping_ips', False)
-        self.plugin_obj = NeutronManager.get_plugin()
+        self.plugin_obj = manager.NeutronManager.get_service_plugins().get(
+            'L3_ROUTER_NAT')
+        self.startHttpPatch()
 
     def tearDown(self):
-        super(RouterDBTestCase, self).tearDown()
-        del test_config['config_files']
+        super(RouterDBTestBase, self).tearDown()
+        del test_lib.test_config['config_files']
+
+
+class RouterDBTestCase(RouterDBTestBase,
+                       test_l3_plugin.L3NatDBIntTestCase):
 
     def test_router_remove_router_interface_wrong_subnet_returns_400(self):
         with self.router() as r:
             with self.subnet() as s:
                 with self.subnet(cidr='10.0.10.0/24') as s1:
-                    with self.port(subnet=s1, no_delete=True) as p:
+                    with self.port(subnet=s1) as p:
                         self._router_interface_action('add',
                                                       r['router']['id'],
                                                       None,
@@ -105,7 +116,7 @@ class RouterDBTestCase(test_base.BigSwitchTestBase,
     def test_router_remove_router_interface_wrong_port_returns_404(self):
         with self.router() as r:
             with self.subnet() as s:
-                with self.port(subnet=s, no_delete=True) as p:
+                with self.port(subnet=s) as p:
                     self._router_interface_action('add',
                                                   r['router']['id'],
                                                   None,
@@ -163,9 +174,9 @@ class RouterDBTestCase(test_base.BigSwitchTestBase,
                         net_id=psub['subnet']['network_id'],
                         port_id=p1['port']['id'],
                         tenant_id=tenant1_id)
-                    multiFloatPatch = patch(
-                        'httplib.HTTPConnection',
-                        create=True,
+                    self.httpPatch.stop()
+                    multiFloatPatch = mock.patch(
+                        HTTPCON,
                         new=fake_server.VerifyMultiTenantFloatingIP)
                     multiFloatPatch.start()
                     fl2 = self._make_floatingip_for_tenant_port(
@@ -173,6 +184,7 @@ class RouterDBTestCase(test_base.BigSwitchTestBase,
                         port_id=p2['port']['id'],
                         tenant_id=tenant2_id)
                     multiFloatPatch.stop()
+                    self.httpPatch.start()
                     self._delete('floatingips', fl1['floatingip']['id'])
                     self._delete('floatingips', fl2['floatingip']['id'])
                     self._router_interface_action(
@@ -250,7 +262,7 @@ class RouterDBTestCase(test_base.BigSwitchTestBase,
     def test_router_remove_interface_wrong_subnet_returns_400(self):
         with self.router() as r:
             with self.subnet(cidr='10.0.10.0/24') as s:
-                with self.port(no_delete=True) as p:
+                with self.port() as p:
                     self._router_interface_action('add',
                                                   r['router']['id'],
                                                   None,
@@ -269,7 +281,7 @@ class RouterDBTestCase(test_base.BigSwitchTestBase,
     def test_router_remove_interface_wrong_port_returns_404(self):
         with self.router() as r:
             with self.subnet(cidr='10.0.10.0/24'):
-                with self.port(no_delete=True) as p:
+                with self.port() as p:
                     self._router_interface_action('add',
                                                   r['router']['id'],
                                                   None,
@@ -292,7 +304,7 @@ class RouterDBTestCase(test_base.BigSwitchTestBase,
 
     def test_send_data(self):
         fmt = 'json'
-        plugin_obj = NeutronManager.get_plugin()
+        plugin_obj = manager.NeutronManager.get_plugin()
 
         with self.router() as r:
             r_id = r['router']['id']
@@ -493,7 +505,7 @@ class RouterDBTestCase(test_base.BigSwitchTestBase,
         cfg.CONF.set_override('max_router_rules', 10, 'ROUTER')
         with self.router() as r:
             rules = []
-            for i in xrange(1, 12):
+            for i in moves.xrange(1, 12):
                 rule = {'source': 'any', 'nexthops': [],
                         'destination': '1.1.1.' + str(i) + '/32',
                         'action': 'permit'}
@@ -504,34 +516,30 @@ class RouterDBTestCase(test_base.BigSwitchTestBase,
 
     def test_rollback_on_router_create(self):
         tid = test_api_v2._uuid()
-        self.errhttpPatch = patch('httplib.HTTPConnection', create=True,
-                                  new=fake_server.HTTPConnectionMock500)
-        self.errhttpPatch.start()
-        self._create_router('json', tid)
-        self.errhttpPatch.stop()
+        self.httpPatch.stop()
+        with mock.patch(HTTPCON, new=fake_server.HTTPConnectionMock500):
+            self._create_router('json', tid)
         self.assertTrue(len(self._get_routers(tid)) == 0)
 
     def test_rollback_on_router_update(self):
         with self.router() as r:
             data = {'router': {'name': 'aNewName'}}
-            self.errhttpPatch = patch('httplib.HTTPConnection', create=True,
-                                      new=fake_server.HTTPConnectionMock500)
-            self.errhttpPatch.start()
-            self.new_update_request('routers', data,
-                                    r['router']['id']).get_response(self.api)
-            self.errhttpPatch.stop()
+            self.httpPatch.stop()
+            with mock.patch(HTTPCON, new=fake_server.HTTPConnectionMock500):
+                self.new_update_request(
+                    'routers', data, r['router']['id']).get_response(self.api)
+            self.httpPatch.start()
             updatedr = self._get_routers(r['router']['tenant_id'])[0]
             # name should have stayed the same due to failure
             self.assertEqual(r['router']['name'], updatedr['name'])
 
     def test_rollback_on_router_delete(self):
         with self.router() as r:
-            self.errhttpPatch = patch('httplib.HTTPConnection', create=True,
-                                      new=fake_server.HTTPConnectionMock500)
-            self.errhttpPatch.start()
-            self._delete('routers', r['router']['id'],
-                         expected_code=exc.HTTPInternalServerError.code)
-            self.errhttpPatch.stop()
+            self.httpPatch.stop()
+            with mock.patch(HTTPCON, new=fake_server.HTTPConnectionMock500):
+                self._delete('routers', r['router']['id'],
+                             expected_code=exc.HTTPInternalServerError.code)
+            self.httpPatch.start()
             self.assertEqual(r['router']['id'],
                              self._get_routers(r['router']['tenant_id']
                                                )[0]['id'])
