@@ -1,5 +1,3 @@
-# vim:  tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Embrane, Inc.
 # All Rights Reserved.
 #
@@ -14,22 +12,15 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
-# @author:  Ivar Lazzaro, Embrane, Inc.
 
-import sys
-
-import mock
 from oslo.config import cfg
 
-from neutron.db import api as db
 from neutron.plugins.embrane.common import config  # noqa
 from neutron.tests.unit import test_extension_extraroute as extraroute_test
 from neutron.tests.unit import test_l3_plugin as router_test
 
 PLUGIN_NAME = ('neutron.plugins.embrane.plugins.embrane_fake_plugin.'
                'EmbraneFakePlugin')
-sys.modules["heleosapi"] = mock.Mock()
 
 
 class TestEmbraneL3NatDBTestCase(router_test.L3NatDBIntTestCase):
@@ -37,7 +28,6 @@ class TestEmbraneL3NatDBTestCase(router_test.L3NatDBIntTestCase):
 
     def setUp(self):
         cfg.CONF.set_override('admin_password', "admin123", 'heleos')
-        self.addCleanup(db.clear_db)
         super(TestEmbraneL3NatDBTestCase, self).setUp()
 
 
