@@ -1,4 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
 # Copyright 2011 OpenStack Foundation.
 # All Rights Reserved.
 #
@@ -14,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from abc import abstractmethod
+import abc
 
 from neutron.api import extensions
 from neutron import wsgi
@@ -60,7 +59,7 @@ class ExtensionExpectingPluginInterface(StubExtension):
 
 class StubPluginInterface(extensions.PluginInterface):
 
-    @abstractmethod
+    @abc.abstractmethod
     def get_foo(self, bar=None):
         pass
 
