@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012, Nachi Ueno, NTT MCL, Inc.
 # All Rights Reserved.
 #
@@ -15,8 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import os
-
 import mock
 from oslo.config import cfg
 import testtools
@@ -24,20 +20,15 @@ import testtools
 from neutron.common import exceptions as exc
 from neutron.common import topics
 from neutron import context
-from neutron.db import api as db
 from neutron.db import db_base_plugin_v2
 from neutron.db import models_v2
-from neutron.extensions.flavor import (FLAVOR_NETWORK, FLAVOR_ROUTER)
+from neutron.extensions import flavor as ext_flavor
 from neutron.openstack.common import uuidutils
-from neutron.plugins.metaplugin.meta_neutron_plugin import (
-    FaildToAddFlavorBinding)
-from neutron.plugins.metaplugin.meta_neutron_plugin import FlavorNotFound
-from neutron.plugins.metaplugin.meta_neutron_plugin import MetaPluginV2
-from neutron.tests import base
+from neutron.plugins.metaplugin import meta_neutron_plugin
+from neutron.tests.unit import testlib_api
+from neutron.tests.unit import testlib_plugin
 
 CONF_FILE = ""
-ROOTDIR = os.path.dirname(os.path.dirname(__file__))
-ETCDIR = os.path.join(ROOTDIR, 'etc')
 META_PATH = "neutron.plugins.metaplugin"
 FAKE_PATH = "neutron.tests.unit.metaplugin"
 PROXY_PATH = "%s.proxy_neutron_plugin.ProxyPluginV2" % META_PATH
@@ -49,10 +40,6 @@ fake1:%s.fake_plugin.Fake1,fake2:%s.fake_plugin.Fake2
 """.strip() % (FAKE_PATH, FAKE_PATH)
 
 
-def etcdir(*p):
-    return os.path.join(ETCDIR, *p)
-
-
 def setup_metaplugin_conf(has_l3=True):
     cfg.CONF.set_override('auth_url', 'http://localhost:35357/v2.0',
                                       'PROXY')
@@ -70,8 +57,6 @@ def setup_metaplugin_conf(has_l3=True):
     cfg.CONF.set_override('base_mac', "12:34:56:78:90:ab")
     #TODO(nati) remove this after subnet quota change is merged
     cfg.CONF.set_override('max_dns_nameservers', 10)
-    cfg.CONF.set_override('rpc_backend',
-                          'neutron.openstack.common.rpc.impl_fake')
 
 
 # Hooks registered by metaplugin must not exist for other plugins UT.
@@ -83,20 +68,17 @@ def unregister_meta_hooks():
         models_v2.Port, 'metaplugin_port', None, None, None)
 
 
-class MetaNeutronPluginV2Test(base.BaseTestCase):
+class MetaNeutronPluginV2Test(testlib_api.SqlTestCase,
+                              testlib_plugin.PluginSetupHelper):
     """Class conisting of MetaNeutronPluginV2 unit tests."""
 
     has_l3 = True
 
     def setUp(self):
         super(MetaNeutronPluginV2Test, self).setUp()
-        db._ENGINE = None
-        db._MAKER = None
         self.fake_tenant_id = uuidutils.generate_uuid()
         self.context = context.get_admin_context()
 
-        db.configure_db()
-        self.addCleanup(db.clear_db)
         self.addCleanup(unregister_meta_hooks)
 
         setup_metaplugin_conf(self.has_l3)
@@ -120,9 +102,10 @@ class MetaNeutronPluginV2Test(base.BaseTestCase):
         self.client_inst.delete_network.return_value = True
         self.client_inst.delete_port.return_value = True
         self.client_inst.delete_subnet.return_value = True
-        plugin = MetaPluginV2.__module__ + '.' + MetaPluginV2.__name__
+        plugin = (meta_neutron_plugin.MetaPluginV2.__module__ + '.'
+                  + meta_neutron_plugin.MetaPluginV2.__name__)
         self.setup_coreplugin(plugin)
-        self.plugin = MetaPluginV2(configfile=None)
+        self.plugin = meta_neutron_plugin.MetaPluginV2(configfile=None)
 
     def _fake_network(self, flavor):
         data = {'network': {'name': flavor,
@@ -130,7 +113,7 @@ class MetaNeutronPluginV2Test(base.BaseTestCase):
                             'shared': False,
                             'router:external': [],
                             'tenant_id': self.fake_tenant_id,
-                            FLAVOR_NETWORK: flavor}}
+                            ext_flavor.FLAVOR_NETWORK: flavor}}
         return data
 
     def _fake_port(self, net_id):
@@ -162,22 +145,22 @@ class MetaNeutronPluginV2Test(base.BaseTestCase):
     def _fake_router(self, flavor):
         data = {'router': {'name': flavor, 'admin_state_up': True,
                            'tenant_id': self.fake_tenant_id,
-                           FLAVOR_ROUTER: flavor,
+                           ext_flavor.FLAVOR_ROUTER: flavor,
                            'external_gateway_info': None}}
         return data
 
     def test_create_delete_network(self):
         network1 = self._fake_network('fake1')
         ret1 = self.plugin.create_network(self.context, network1)
-        self.assertEqual('fake1', ret1[FLAVOR_NETWORK])
+        self.assertEqual('fake1', ret1[ext_flavor.FLAVOR_NETWORK])
 
         network2 = self._fake_network('fake2')
         ret2 = self.plugin.create_network(self.context, network2)
-        self.assertEqual('fake2', ret2[FLAVOR_NETWORK])
+        self.assertEqual('fake2', ret2[ext_flavor.FLAVOR_NETWORK])
 
         network3 = self._fake_network('proxy')
         ret3 = self.plugin.create_network(self.context, network3)
-        self.assertEqual('proxy', ret3[FLAVOR_NETWORK])
+        self.assertEqual('proxy', ret3[ext_flavor.FLAVOR_NETWORK])
 
         db_ret1 = self.plugin.get_network(self.context, ret1['id'])
         self.assertEqual('fake1', db_ret1['name'])
@@ -191,8 +174,9 @@ class MetaNeutronPluginV2Test(base.BaseTestCase):
         db_ret4 = self.plugin.get_networks(self.context)
         self.assertEqual(3, len(db_ret4))
 
-        db_ret5 = self.plugin.get_networks(self.context,
-                                           {FLAVOR_NETWORK: ['fake1']})
+        db_ret5 = self.plugin.get_networks(
+            self.context,
+            {ext_flavor.FLAVOR_NETWORK: ['fake1']})
         self.assertEqual(1, len(db_ret5))
         self.assertEqual('fake1', db_ret5[0]['name'])
         self.plugin.delete_network(self.context, ret1['id'])
@@ -307,18 +291,18 @@ class MetaNeutronPluginV2Test(base.BaseTestCase):
         router2 = self._fake_router('fake2')
         router_ret2 = self.plugin.create_router(self.context, router2)
 
-        self.assertEqual('fake1', router_ret1[FLAVOR_ROUTER])
-        self.assertEqual('fake2', router_ret2[FLAVOR_ROUTER])
+        self.assertEqual('fake1', router_ret1[ext_flavor.FLAVOR_ROUTER])
+        self.assertEqual('fake2', router_ret2[ext_flavor.FLAVOR_ROUTER])
 
         router_in_db1 = self.plugin.get_router(self.context, router_ret1['id'])
         router_in_db2 = self.plugin.get_router(self.context, router_ret2['id'])
 
-        self.assertEqual('fake1', router_in_db1[FLAVOR_ROUTER])
-        self.assertEqual('fake2', router_in_db2[FLAVOR_ROUTER])
+        self.assertEqual('fake1', router_in_db1[ext_flavor.FLAVOR_ROUTER])
+        self.assertEqual('fake2', router_in_db2[ext_flavor.FLAVOR_ROUTER])
 
         self.plugin.delete_router(self.context, router_ret1['id'])
         self.plugin.delete_router(self.context, router_ret2['id'])
-        with testtools.ExpectedException(FlavorNotFound):
+        with testtools.ExpectedException(meta_neutron_plugin.FlavorNotFound):
             self.plugin.get_router(self.context, router_ret1['id'])
 
     def test_extension_method(self):
@@ -340,7 +324,7 @@ class MetaNeutronPluginV2Test(base.BaseTestCase):
                         'add_network_flavor_binding',
                         side_effect=Exception):
             network = self._fake_network('fake1')
-            self.assertRaises(FaildToAddFlavorBinding,
+            self.assertRaises(meta_neutron_plugin.FaildToAddFlavorBinding,
                               self.plugin.create_network,
                               self.context,
                               network)
@@ -352,7 +336,7 @@ class MetaNeutronPluginV2Test(base.BaseTestCase):
                         'add_router_flavor_binding',
                         side_effect=Exception):
             router = self._fake_router('fake1')
-            self.assertRaises(FaildToAddFlavorBinding,
+            self.assertRaises(meta_neutron_plugin.FaildToAddFlavorBinding,
                               self.plugin.create_router,
                               self.context,
                               router)
@@ -376,21 +360,17 @@ class MetaNeutronPluginV2TestWithoutL3(MetaNeutronPluginV2Test):
         self.skipTest("Test case without router")
 
 
-class MetaNeutronPluginV2TestRpcFlavor(base.BaseTestCase):
+class MetaNeutronPluginV2TestRpcFlavor(testlib_api.SqlTestCase):
     """Tests for rpc_flavor."""
 
     def setUp(self):
         super(MetaNeutronPluginV2TestRpcFlavor, self).setUp()
-        db._ENGINE = None
-        db._MAKER = None
-        db.configure_db()
-        self.addCleanup(db.clear_db)
         self.addCleanup(unregister_meta_hooks)
 
     def test_rpc_flavor(self):
         setup_metaplugin_conf()
         cfg.CONF.set_override('rpc_flavor', 'fake1', 'META')
-        self.plugin = MetaPluginV2()
+        self.plugin = meta_neutron_plugin.MetaPluginV2()
         self.assertEqual(topics.PLUGIN, 'q-plugin')
         ret = self.plugin.rpc_workers_supported()
         self.assertFalse(ret)
@@ -399,15 +379,15 @@ class MetaNeutronPluginV2TestRpcFlavor(base.BaseTestCase):
         setup_metaplugin_conf()
         cfg.CONF.set_override('rpc_flavor', 'fake-fake', 'META')
         self.assertRaises(exc.Invalid,
-                          MetaPluginV2)
+                          meta_neutron_plugin.MetaPluginV2)
         self.assertEqual(topics.PLUGIN, 'q-plugin')
 
     def test_rpc_flavor_multiple_rpc_workers(self):
         setup_metaplugin_conf()
         cfg.CONF.set_override('rpc_flavor', 'fake2', 'META')
-        self.plugin = MetaPluginV2()
+        self.plugin = meta_neutron_plugin.MetaPluginV2()
         self.assertEqual(topics.PLUGIN, 'q-plugin')
         ret = self.plugin.rpc_workers_supported()
         self.assertTrue(ret)
-        ret = self.plugin.start_rpc_listener()
+        ret = self.plugin.start_rpc_listeners()
         self.assertEqual('OK', ret)
