@@ -39,7 +39,7 @@ class PortBindingTestCase(test_plugin.NeutronDbPluginV2TestCase):
         super(PortBindingTestCase, self).setUp(PLUGIN_NAME)
         self.port_create_status = 'DOWN'
         self.plugin = manager.NeutronManager.get_plugin()
-        self.plugin.start_rpc_listener()
+        self.plugin.start_rpc_listeners()
 
     def _check_response(self, port, vif_type, has_port_filter, bound, status):
         self.assertEqual(port[portbindings.VIF_TYPE], vif_type)
@@ -55,19 +55,23 @@ class PortBindingTestCase(test_plugin.NeutronDbPluginV2TestCase):
 
     def _test_port_binding(self, host, vif_type, has_port_filter, bound,
                            status=None):
-        host_arg = {portbindings.HOST_ID: host}
+        mac_address = 'aa:aa:aa:aa:aa:aa'
+        host_arg = {portbindings.HOST_ID: host,
+                    'mac_address': mac_address}
         with self.port(name='name', arg_list=(portbindings.HOST_ID,),
                        **host_arg) as port:
             self._check_response(port['port'], vif_type, has_port_filter,
                                  bound, status)
             port_id = port['port']['id']
             neutron_context = context.get_admin_context()
-            details = self.plugin.callbacks.get_device_details(
+            details = self.plugin.endpoints[0].get_device_details(
                 neutron_context, agent_id="theAgentId", device=port_id)
             if bound:
                 self.assertEqual(details['network_type'], 'local')
+                self.assertEqual(mac_address, details['mac_address'])
             else:
                 self.assertNotIn('network_type', details)
+                self.assertNotIn('mac_address', details)
 
     def test_unbound(self):
         self._test_port_binding("",
