@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright (c) 2013 OpenStack Foundation.
 # All Rights Reserved.
 #
@@ -161,6 +159,25 @@ class AgentDBTestMixIn(object):
                               time=timeutils.strtime())
         return [dhcp_host]
 
+    def _register_one_l3_agent(self, host=L3_HOSTA, internal_only=True,
+                               ext_net_id='', ext_bridge=''):
+        l3 = {
+            'binary': 'neutron-l3-agent',
+            'host': host,
+            'topic': topics.L3_AGENT,
+            'configurations': {'use_namespaces': True,
+                               'router_id': None,
+                               'handle_internal_only_routers': internal_only,
+                               'external_network_bridge': ext_bridge,
+                               'gateway_external_network_id': ext_net_id,
+                               'interface_driver': 'interface_driver',
+                               },
+            'agent_type': constants.AGENT_TYPE_L3}
+        callback = agents_db.AgentExtRpcCallback()
+        callback.report_state(self.adminContext,
+                              agent_state={'agent_state': l3},
+                              time=timeutils.strtime())
+
 
 class AgentDBTestCase(AgentDBTestMixIn,
                       test_db_plugin.NeutronDbPluginV2TestCase):
