@@ -15,8 +15,6 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
-# @author: Isaku Yamahata, Intel Corporation.
 
 import uuid
 
@@ -27,14 +25,15 @@ import webtest
 
 from neutron.api import extensions
 from neutron.api.v2 import attributes
-from neutron.common import config
 from neutron import quota
 from neutron.tests.unit import test_api_v2
 from neutron.tests.unit import test_extensions
 from neutron.tests.unit import testlib_api
+from neutron.tests.unit import testlib_plugin
 
 
-class ExtensionTestCase(testlib_api.WebTestCase):
+class ExtensionTestCase(testlib_api.WebTestCase,
+                        testlib_plugin.PluginSetupHelper):
     def _resotre_attr_map(self):
         attributes.RESOURCE_ATTRIBUTE_MAP = self._saved_attr_map
 
@@ -60,8 +59,7 @@ class ExtensionTestCase(testlib_api.WebTestCase):
         self.addCleanup(self._resotre_attr_map)
 
         # Create the default configurations
-        args = ['--config-file', test_api_v2.etcdir('neutron.conf.test')]
-        config.parse(args)
+        self.config_parse()
 
         #just stubbing core plugin with plugin
         self.setup_coreplugin(plugin)
