@@ -106,6 +106,9 @@ fake_meta_port = dhcp.DictModel(dict(id='12345678-1234-aaaa-1234567890ab',
                                 device_id='forzanapoli',
                                 fixed_ips=[fake_meta_fixed_ip]))
 
+fake_meta_dvr_port = dhcp.DictModel(fake_meta_port.copy())
+fake_meta_dvr_port.device_owner = const.DEVICE_OWNER_DVR_INTERFACE
+
 fake_dist_port = dhcp.DictModel(dict(id='12345678-1234-aaaa-1234567890ab',
                                 mac_address='aa:bb:cc:dd:ee:ff',
                                 network_id='12345678-1234-5678-1234567890ab',
@@ -163,6 +166,9 @@ fake_meta_network = dhcp.NetModel(
                subnets=[fake_meta_subnet],
                ports=[fake_meta_port]))
 
+fake_meta_dvr_network = dhcp.NetModel(True, fake_meta_network.copy())
+fake_meta_dvr_network.ports = [fake_meta_dvr_port]
+
 fake_dist_network = dhcp.NetModel(
     True, dict(id='12345678-1234-5678-1234567890ab',
                tenant_id='aaaaaaaa-aaaa-aaaa-aaaaaaaaaaaa',
@@ -282,6 +288,11 @@ class TestDhcpAgent(base.BaseTestCase):
                 self.assertEqual(log.call_count, 1)
                 self.assertEqual(expected_sync, schedule_resync.called)
 
+    def test_call_driver_ip_address_generation_failure(self):
+        error = n_rpc.RemoteError(
+            exc_type='IpAddressGenerationFailure')
+        self._test_call_driver_failure(exc=error, expected_sync=False)
+
     def test_call_driver_failure(self):
         self._test_call_driver_failure()
 
@@ -795,6 +806,9 @@ class TestDhcpAgentEventHandler(base.BaseTestCase):
     def test_enable_isolated_metadata_proxy_with_metadata_network(self):
         self._test_metadata_network(fake_meta_network)
 
+    def test_enable_isolated_metadata_proxy_with_metadata_network_dvr(self):
+        self._test_metadata_network(fake_meta_dvr_network)
+
     def test_enable_isolated_metadata_proxy_with_dist_network(self):
         self._test_metadata_network(fake_dist_network)
 
