@@ -20,10 +20,11 @@ from neutron.db import db_base_plugin_v2
 from neutron.db import portsecurity_db
 from neutron.extensions import allowedaddresspairs as addr_pair
 from neutron.extensions import portsecurity as psec
-from neutron.manager import NeutronManager
+from neutron import manager
 from neutron.tests.unit import test_db_plugin
 from oslo.config import cfg
 
+
 DB_PLUGIN_KLASS = ('neutron.tests.unit.test_extension_allowedaddresspairs.'
                    'AllowedAddressPairTestPlugin')
 
@@ -33,7 +34,7 @@ class AllowedAddressPairTestCase(test_db_plugin.NeutronDbPluginV2TestCase):
         super(AllowedAddressPairTestCase, self).setUp(plugin)
 
         # Check if a plugin supports security groups
-        plugin_obj = NeutronManager.get_plugin()
+        plugin_obj = manager.NeutronManager.get_plugin()
         self._skip_port_security = ('port-security' not in
                                     plugin_obj.supported_extension_aliases)
 
@@ -64,7 +65,6 @@ class AllowedAddressPairTestPlugin(portsecurity_db.PortSecurityDbMixin,
         return port['port']
 
     def update_port(self, context, id, port):
-        changed_fixed_ips = 'fixed_ips' in port['port']
         delete_addr_pairs = self._check_update_deletes_allowed_address_pairs(
             port)
         has_addr_pairs = self._check_update_has_allowed_address_pairs(port)
@@ -82,9 +82,6 @@ class AllowedAddressPairTestPlugin(portsecurity_db.PortSecurityDbMixin,
                 self._process_create_allowed_address_pairs(
                     context, ret_port,
                     ret_port[addr_pair.ADDRESS_PAIRS])
-            elif changed_fixed_ips:
-                self._check_fixed_ips_and_address_pairs_no_overlap(context,
-                                                                   ret_port)
 
         return ret_port
 
@@ -143,6 +140,11 @@ class TestAllowedAddressPairs(AllowedAddressPairDBTestCase):
             self.deserialize(self.fmt, res)
             self.assertEqual(res.status_int, 409)
 
+    def test_create_port_zero_prefix_ip(self):
+        address_pairs = [{'mac_address': 'invalid_mac',
+                          'ip_address': '0.0.0.0/0'}]
+        self._create_port_with_address_pairs(address_pairs, 400)
+
     def test_create_port_bad_mac(self):
         address_pairs = [{'mac_address': 'invalid_mac',
                           'ip_address': '10.0.0.1'}]
@@ -186,6 +188,22 @@ class TestAllowedAddressPairs(AllowedAddressPairDBTestCase):
                           'ip_address': '10.0.0.3'}]
         self._create_port_with_address_pairs(address_pairs, 201)
 
+    def test_create_overlap_with_fixed_ip(self):
+        address_pairs = [{'mac_address': '00:00:00:00:00:01',
+                          'ip_address': '10.0.0.2'}]
+        with self.network() as network:
+            with self.subnet(network=network, cidr='10.0.0.0/24') as subnet:
+                fixed_ips = [{'subnet_id': subnet['subnet']['id'],
+                              'ip_address': '10.0.0.2'}]
+                res = self._create_port(self.fmt, network['network']['id'],
+                                        arg_list=(addr_pair.ADDRESS_PAIRS,
+                                        'fixed_ips'),
+                                        allowed_address_pairs=address_pairs,
+                                        fixed_ips=fixed_ips)
+                self.assertEqual(res.status_int, 201)
+                port = self.deserialize(self.fmt, res)
+                self._delete('ports', port['port']['id'])
+
     def test_create_port_extra_args(self):
         address_pairs = [{'mac_address': '00:00:00:00:00:01',
                           'ip_address': '10.0.0.1',
@@ -217,34 +235,6 @@ class TestAllowedAddressPairs(AllowedAddressPairDBTestCase):
                              address_pairs)
             self._delete('ports', port['port']['id'])
 
-    def test_update_fixed_ip_to_address_pair_ip_fail(self):
-        with self.network() as net:
-            with self.subnet(network=net):
-                address_pairs = [{'ip_address': '10.0.0.65'}]
-                res = self._create_port(self.fmt, net['network']['id'],
-                                        arg_list=(addr_pair.ADDRESS_PAIRS,),
-                                        allowed_address_pairs=address_pairs)
-                port = self.deserialize(self.fmt, res)['port']
-                data = {'port': {'fixed_ips': [{'ip_address': '10.0.0.65'}]}}
-                req = self.new_update_request('ports', data, port['id'])
-                res = req.get_response(self.api)
-                self.assertEqual(res.status_int, 400)
-                self._delete('ports', port['id'])
-
-    def test_update_fixed_ip_to_address_pair_with_mac_fail(self):
-        with self.network() as net:
-            with self.subnet(network=net):
-                res = self._create_port(self.fmt, net['network']['id'])
-                port = self.deserialize(self.fmt, res)['port']
-                address_pairs = [
-                    {'mac_address': port['mac_address'],
-                     'ip_address': port['fixed_ips'][0]['ip_address']}]
-                data = {'port': {addr_pair.ADDRESS_PAIRS: address_pairs}}
-                req = self.new_update_request('ports', data, port['id'])
-                res = req.get_response(self.api)
-                self.assertEqual(res.status_int, 400)
-                self._delete('ports', port['id'])
-
     def test_create_address_gets_port_mac(self):
         with self.network() as net:
             address_pairs = [{'ip_address': '23.23.23.23'}]
@@ -258,23 +248,6 @@ class TestAllowedAddressPairs(AllowedAddressPairDBTestCase):
                              port['mac_address'])
             self._delete('ports', port['id'])
 
-    def test_update_address_pair_to_match_fixed_ip_and_mac(self):
-        with self.network() as net:
-            with self.subnet(network=net):
-                res = self._create_port(self.fmt, net['network']['id'])
-                port = self.deserialize(self.fmt, res)['port']
-                address_pairs = [{'mac_address': port['mac_address'],
-                                  'ip_address':
-                                  port['fixed_ips'][0]['ip_address']}]
-
-                update_port = {'port': {addr_pair.ADDRESS_PAIRS:
-                                        address_pairs}}
-                req = self.new_update_request('ports', update_port,
-                                              port['id'])
-                res = req.get_response(self.api)
-                self.assertEqual(res.status_int, 400)
-                self._delete('ports', port['id'])
-
     def test_update_port_security_off_address_pairs(self):
         if self._skip_port_security:
             self.skipTest("Plugin does not implement port-security extension")
@@ -291,7 +264,7 @@ class TestAllowedAddressPairs(AllowedAddressPairDBTestCase):
                 update_port = {'port': {psec.PORTSECURITY: False}}
                 # If plugin implements security groups we also need to remove
                 # the security group on port.
-                plugin_obj = NeutronManager.get_plugin()
+                plugin_obj = manager.NeutronManager.get_plugin()
                 if 'security-groups' in plugin_obj.supported_extension_aliases:
                     update_port['port']['security_groups'] = []
                 req = self.new_update_request('ports', update_port,
