@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright (c) 2011 OpenStack Foundation.
 # All Rights Reserved.
 #
@@ -15,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import os
+import abc
 
 import mock
 import routes
@@ -37,14 +35,6 @@ from neutron import wsgi
 
 
 LOG = logging.getLogger(__name__)
-
-ROOTDIR = os.path.dirname(os.path.dirname(__file__))
-ETCDIR = os.path.join(ROOTDIR, 'etc')
-
-
-def etcdir(*p):
-    return os.path.join(ETCDIR, *p)
-
 extensions_path = ':'.join(neutron.tests.unit.extensions.__path__)
 
 
@@ -67,6 +57,47 @@ class FakePluginWithExtension(db_base_plugin_v2.NeutronDbPluginV2):
         self._log("method_to_support_foxnsox_extension", context)
 
 
+class PluginInterfaceTest(base.BaseTestCase):
+    def test_issubclass_hook(self):
+        class A(object):
+            def f(self):
+                pass
+
+        class B(extensions.PluginInterface):
+            @abc.abstractmethod
+            def f(self):
+                pass
+
+        self.assertTrue(issubclass(A, B))
+
+    def test_issubclass_hook_class_without_abstract_methods(self):
+        class A(object):
+            def f(self):
+                pass
+
+        class B(extensions.PluginInterface):
+            def f(self):
+                pass
+
+        self.assertFalse(issubclass(A, B))
+
+    def test_issubclass_hook_not_all_methods_implemented(self):
+        class A(object):
+            def f(self):
+                pass
+
+        class B(extensions.PluginInterface):
+            @abc.abstractmethod
+            def f(self):
+                pass
+
+            @abc.abstractmethod
+            def g(self):
+                pass
+
+        self.assertFalse(issubclass(A, B))
+
+
 class ResourceExtensionTest(base.BaseTestCase):
 
     class ResourceExtensionController(wsgi.Controller):
@@ -404,7 +435,7 @@ class RequestExtensionTest(base.BaseTestCase):
             res.body = jsonutils.dumps(data)
             return res
 
-        base_app = webtest.TestApp(setup_base_app())
+        base_app = webtest.TestApp(setup_base_app(self))
         response = base_app.put("/dummy_resources/1",
                                 {'uneditable': "new_value"})
         self.assertEqual(response.json['uneditable'], "original_value")
@@ -606,10 +637,8 @@ def app_factory(global_conf, **local_conf):
     return ExtensionsTestApp(conf)
 
 
-def setup_base_app():
-    config_file = 'neutron.conf.test'
-    args = ['--config-file', etcdir(config_file)]
-    config.parse(args=args)
+def setup_base_app(test):
+    base.BaseTestCase.config_parse()
     app = config.load_paste_app('extensions_test_app')
     return app
 
@@ -619,9 +648,7 @@ def setup_extensions_middleware(extension_manager=None):
                          extensions.PluginAwareExtensionManager(
                              extensions_path,
                              {constants.CORE: FakePluginWithExtension()}))
-    config_file = 'neutron.conf.test'
-    args = ['--config-file', etcdir(config_file)]
-    config.parse(args=args)
+    base.BaseTestCase.config_parse()
     app = config.load_paste_app('extensions_test_app')
     return extensions.ExtensionMiddleware(app, ext_mgr=extension_manager)
 
