@@ -83,11 +83,11 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                                     '-m physdev --physdev-out tapfake_dev '
                                     '--physdev-is-bridged '
                                     '-j $ifake_dev'),
-                 mock.call.add_rule(
-                     'ifake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule(
                      'ifake_dev',
                      '-m state --state RELATED,ESTABLISHED -j RETURN'),
+                 mock.call.add_rule(
+                     'ifake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule('ifake_dev', '-j $sg-fallback'),
                  mock.call.add_chain('ofake_dev'),
                  mock.call.add_rule('FORWARD',
@@ -104,8 +104,9 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                                     '-j $ofake_dev'),
                  mock.call.add_chain('sfake_dev'),
                  mock.call.add_rule(
-                     'sfake_dev', '-m mac --mac-source ff:ff:ff:ff:ff:ff '
-                     '-s 10.0.0.1 -j RETURN'),
+                     'sfake_dev',
+                     '-s 10.0.0.1 -m mac --mac-source FF:FF:FF:FF:FF:FF '
+                     '-j RETURN'),
                  mock.call.add_rule('sfake_dev', '-j DROP'),
                  mock.call.add_rule(
                      'ofake_dev',
@@ -114,11 +115,11 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                  mock.call.add_rule(
                      'ofake_dev',
                      '-p udp -m udp --sport 67 --dport 68 -j DROP'),
-                 mock.call.add_rule(
-                     'ofake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule(
                      'ofake_dev',
                      '-m state --state RELATED,ESTABLISHED -j RETURN'),
+                 mock.call.add_rule(
+                     'ofake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule('ofake_dev', '-j $sg-fallback'),
                  mock.call.add_rule('sg-chain', '-j ACCEPT')]
 
@@ -843,16 +844,16 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                     mock.call.add_rule('ifake_dev',
                                        '-p icmpv6 --icmpv6-type %s -j RETURN' %
                                        icmp6_type))
-        calls += [mock.call.add_rule('ifake_dev',
-                                     '-m state --state INVALID -j DROP'),
-                  mock.call.add_rule(
+        calls += [mock.call.add_rule(
                       'ifake_dev',
                       '-m state --state RELATED,ESTABLISHED -j RETURN')]
 
         if ingress_expected_call:
             calls.append(ingress_expected_call)
 
-        calls += [mock.call.add_rule('ifake_dev', '-j $sg-fallback'),
+        calls += [mock.call.add_rule('ifake_dev',
+                                     '-m state --state INVALID -j DROP'),
+                  mock.call.add_rule('ifake_dev', '-j $sg-fallback'),
                   mock.call.add_chain('ofake_dev'),
                   mock.call.add_rule('FORWARD',
                                      '-m physdev --physdev-in tapfake_dev '
@@ -869,7 +870,7 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                   mock.call.add_chain('sfake_dev'),
                   mock.call.add_rule(
                       'sfake_dev',
-                      '-m mac --mac-source ff:ff:ff:ff:ff:ff -s %s -j RETURN'
+                      '-s %s -m mac --mac-source FF:FF:FF:FF:FF:FF -j RETURN'
                       % prefix),
                   mock.call.add_rule('sfake_dev', '-j DROP')]
         calls += dhcp_rule
@@ -884,15 +885,15 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                 '-p udp -m udp --sport 547 --dport 546 -j DROP'))
 
         calls += [mock.call.add_rule(
-                  'ofake_dev', '-m state --state INVALID -j DROP'),
-                  mock.call.add_rule(
                       'ofake_dev',
                       '-m state --state RELATED,ESTABLISHED -j RETURN')]
 
         if egress_expected_call:
             calls.append(egress_expected_call)
 
-        calls += [mock.call.add_rule('ofake_dev', '-j $sg-fallback'),
+        calls += [mock.call.add_rule(
+                  'ofake_dev', '-m state --state INVALID -j DROP'),
+                  mock.call.add_rule('ofake_dev', '-j $sg-fallback'),
                   mock.call.add_rule('sg-chain', '-j ACCEPT')]
 
         filter_inst.assert_has_calls(calls)
@@ -921,12 +922,12 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                      'sg-chain',
                      '-m physdev --physdev-out tapfake_dev '
                      '--physdev-is-bridged -j $ifake_dev'),
-                 mock.call.add_rule(
-                     'ifake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule(
                      'ifake_dev',
                      '-m state --state RELATED,ESTABLISHED -j RETURN'),
                  mock.call.add_rule('ifake_dev', '-j RETURN'),
+                 mock.call.add_rule(
+                     'ifake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule('ifake_dev', '-j $sg-fallback'),
                  mock.call.add_chain('ofake_dev'),
                  mock.call.add_rule(
@@ -944,7 +945,7 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                  mock.call.add_chain('sfake_dev'),
                  mock.call.add_rule(
                      'sfake_dev',
-                     '-m mac --mac-source ff:ff:ff:ff:ff:ff -s 10.0.0.1 '
+                     '-s 10.0.0.1 -m mac --mac-source FF:FF:FF:FF:FF:FF '
                      '-j RETURN'),
                  mock.call.add_rule('sfake_dev', '-j DROP'),
                  mock.call.add_rule(
@@ -954,11 +955,11 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                  mock.call.add_rule(
                      'ofake_dev',
                      '-p udp -m udp --sport 67 --dport 68 -j DROP'),
-                 mock.call.add_rule(
-                     'ofake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule(
                      'ofake_dev',
                      '-m state --state RELATED,ESTABLISHED -j RETURN'),
+                 mock.call.add_rule(
+                     'ofake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule('ofake_dev', '-j $sg-fallback'),
                  mock.call.add_rule('sg-chain', '-j ACCEPT'),
                  mock.call.ensure_remove_chain('ifake_dev'),
@@ -977,10 +978,10 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                      '--physdev-is-bridged -j $ifake_dev'),
                  mock.call.add_rule(
                      'ifake_dev',
-                     '-m state --state INVALID -j DROP'),
+                     '-m state --state RELATED,ESTABLISHED -j RETURN'),
                  mock.call.add_rule(
                      'ifake_dev',
-                     '-m state --state RELATED,ESTABLISHED -j RETURN'),
+                     '-m state --state INVALID -j DROP'),
                  mock.call.add_rule('ifake_dev', '-j $sg-fallback'),
                  mock.call.add_chain('ofake_dev'),
                  mock.call.add_rule(
@@ -998,7 +999,7 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                  mock.call.add_chain('sfake_dev'),
                  mock.call.add_rule(
                      'sfake_dev',
-                     '-m mac --mac-source ff:ff:ff:ff:ff:ff -s 10.0.0.1 '
+                     '-s 10.0.0.1 -m mac --mac-source FF:FF:FF:FF:FF:FF '
                      '-j RETURN'),
                  mock.call.add_rule('sfake_dev', '-j DROP'),
                  mock.call.add_rule(
@@ -1008,12 +1009,12 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                  mock.call.add_rule(
                      'ofake_dev',
                      '-p udp -m udp --sport 67 --dport 68 -j DROP'),
-                 mock.call.add_rule(
-                     'ofake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule(
                      'ofake_dev',
                      '-m state --state RELATED,ESTABLISHED -j RETURN'),
                  mock.call.add_rule('ofake_dev', '-j RETURN'),
+                 mock.call.add_rule(
+                     'ofake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule('ofake_dev', '-j $sg-fallback'),
                  mock.call.add_rule('sg-chain', '-j ACCEPT'),
                  mock.call.ensure_remove_chain('ifake_dev'),
@@ -1128,11 +1129,11 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                                     '-m physdev --physdev-out tapfake_dev '
                                     '--physdev-is-bridged '
                                     '-j $ifake_dev'),
-                 mock.call.add_rule(
-                     'ifake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule(
                      'ifake_dev',
                      '-m state --state RELATED,ESTABLISHED -j RETURN'),
+                 mock.call.add_rule(
+                     'ifake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule('ifake_dev', '-j $sg-fallback'),
                  mock.call.add_chain('ofake_dev'),
                  mock.call.add_rule('FORWARD',
@@ -1150,11 +1151,11 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                  mock.call.add_chain('sfake_dev'),
                  mock.call.add_rule(
                      'sfake_dev',
-                     '-m mac --mac-source ff:ff:ff:ff:ff:ff -s 10.0.0.1 '
+                     '-s 10.0.0.1 -m mac --mac-source FF:FF:FF:FF:FF:FF '
                      '-j RETURN'),
                  mock.call.add_rule(
                      'sfake_dev',
-                     '-m mac --mac-source ff:ff:ff:ff:ff:ff -s 10.0.0.2 '
+                     '-s 10.0.0.2 -m mac --mac-source FF:FF:FF:FF:FF:FF '
                      '-j RETURN'),
                  mock.call.add_rule('sfake_dev', '-j DROP'),
                  mock.call.add_rule(
@@ -1164,11 +1165,11 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                  mock.call.add_rule(
                      'ofake_dev',
                      '-p udp -m udp --sport 67 --dport 68 -j DROP'),
-                 mock.call.add_rule(
-                     'ofake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule(
                      'ofake_dev',
                      '-m state --state RELATED,ESTABLISHED -j RETURN'),
+                 mock.call.add_rule(
+                     'ofake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule('ofake_dev', '-j $sg-fallback'),
                  mock.call.add_rule('sg-chain', '-j ACCEPT')]
         self.v4filter_inst.assert_has_calls(calls)
@@ -1191,11 +1192,11 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                                     '-m physdev --physdev-out tapfake_dev '
                                     '--physdev-is-bridged '
                                     '-j $ifake_dev'),
-                 mock.call.add_rule(
-                     'ifake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule(
                      'ifake_dev',
                      '-m state --state RELATED,ESTABLISHED -j RETURN'),
+                 mock.call.add_rule(
+                     'ifake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule('ifake_dev', '-j $sg-fallback'),
                  mock.call.add_chain('ofake_dev'),
                  mock.call.add_rule('FORWARD',
@@ -1213,7 +1214,7 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                  mock.call.add_chain('sfake_dev'),
                  mock.call.add_rule(
                      'sfake_dev',
-                     '-m mac --mac-source ff:ff:ff:ff:ff:ff -j RETURN'),
+                     '-m mac --mac-source FF:FF:FF:FF:FF:FF -j RETURN'),
                  mock.call.add_rule('sfake_dev', '-j DROP'),
                  mock.call.add_rule(
                      'ofake_dev',
@@ -1222,11 +1223,11 @@ class IptablesFirewallTestCase(BaseIptablesFirewallTestCase):
                  mock.call.add_rule(
                      'ofake_dev',
                      '-p udp -m udp --sport 67 --dport 68 -j DROP'),
-                 mock.call.add_rule(
-                     'ofake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule(
                      'ofake_dev',
                      '-m state --state RELATED,ESTABLISHED -j RETURN'),
+                 mock.call.add_rule(
+                     'ofake_dev', '-m state --state INVALID -j DROP'),
                  mock.call.add_rule('ofake_dev', '-j $sg-fallback'),
                  mock.call.add_rule('sg-chain', '-j ACCEPT')]
         self.v4filter_inst.assert_has_calls(calls)
@@ -1256,12 +1257,12 @@ class IptablesFirewallEnhancedIpsetTestCase(BaseIptablesFirewallTestCase):
         self.firewall.pre_sg_members = {}
         port = self._fake_port()
         self.firewall.prepare_port_filter(port)
-        calls = [mock.call.create_ipset_chain('IPv4fake_sgid', 'IPv4'),
+        calls = [mock.call.create_ipset_chain('NETIPv4fake_sgid', 'IPv4'),
                  mock.call.refresh_ipset_chain_by_name(
-                     'IPv4fake_sgid', ['10.0.0.1', '10.0.0.2'], 'IPv4'),
-                 mock.call.create_ipset_chain('IPv6fake_sgid', 'IPv6'),
+                     'NETIPv4fake_sgid', ['10.0.0.1', '10.0.0.2'], 'IPv4'),
+                 mock.call.create_ipset_chain('NETIPv6fake_sgid', 'IPv6'),
                  mock.call.refresh_ipset_chain_by_name(
-                     'IPv6fake_sgid', ['fe80::1'], 'IPv6')]
+                     'NETIPv6fake_sgid', ['fe80::1'], 'IPv6')]
 
         self.firewall.ipset.assert_has_calls(calls)
 
@@ -1273,18 +1274,18 @@ class IptablesFirewallEnhancedIpsetTestCase(BaseIptablesFirewallTestCase):
         self.firewall.pre_sg_members = {}
         port = self._fake_port()
         self.firewall.prepare_port_filter(port)
-        calls = [mock.call.create_ipset_chain('IPv4fake_sgid', 'IPv4'),
+        calls = [mock.call.create_ipset_chain('NETIPv4fake_sgid', 'IPv4'),
                  mock.call.refresh_ipset_chain_by_name(
-                     'IPv4fake_sgid', TEST_IP_RANGE[:5], 'IPv4'),
-                 mock.call.create_ipset_chain('IPv6fake_sgid', 'IPv6'),
+                     'NETIPv4fake_sgid', TEST_IP_RANGE[:5], 'IPv4'),
+                 mock.call.create_ipset_chain('NETIPv6fake_sgid', 'IPv6'),
                  mock.call.refresh_ipset_chain_by_name(
-                     'IPv6fake_sgid', ['fe80::1'], 'IPv6')]
+                     'NETIPv6fake_sgid', ['fe80::1'], 'IPv6')]
 
         self.firewall.ipset.assert_has_calls(calls)
 
     def test_prepare_port_filter_with_ipset_chain_exist(self):
         self.firewall.sg_rules = self._fake_sg_rule()
-        self.firewall.ipset_chains = {'IPv4fake_sgid': ['10.0.0.2']}
+        self.firewall.ipset_chains = {'NETIPv4fake_sgid': ['10.0.0.2']}
         self.firewall.sg_members = {'fake_sgid': {
             'IPv4': TEST_IP_RANGE[:5],
             'IPv6': ['fe80::1']}}
@@ -1294,19 +1295,23 @@ class IptablesFirewallEnhancedIpsetTestCase(BaseIptablesFirewallTestCase):
         port = self._fake_port()
         self.firewall.prepare_port_filter(port)
         calls = [
-            mock.call.add_member_to_ipset_chain('IPv4fake_sgid', '10.0.0.1'),
-            mock.call.add_member_to_ipset_chain('IPv4fake_sgid', '10.0.0.3'),
-            mock.call.add_member_to_ipset_chain('IPv4fake_sgid', '10.0.0.4'),
-            mock.call.add_member_to_ipset_chain('IPv4fake_sgid', '10.0.0.5'),
-            mock.call.create_ipset_chain('IPv6fake_sgid', 'IPv6'),
+            mock.call.add_member_to_ipset_chain('NETIPv4fake_sgid',
+                                                '10.0.0.1'),
+            mock.call.add_member_to_ipset_chain('NETIPv4fake_sgid',
+                                                '10.0.0.3'),
+            mock.call.add_member_to_ipset_chain('NETIPv4fake_sgid',
+                                                '10.0.0.4'),
+            mock.call.add_member_to_ipset_chain('NETIPv4fake_sgid',
+                                                '10.0.0.5'),
+            mock.call.create_ipset_chain('NETIPv6fake_sgid', 'IPv6'),
             mock.call.refresh_ipset_chain_by_name(
-                'IPv6fake_sgid', ['fe80::1'], 'IPv6')]
+                'NETIPv6fake_sgid', ['fe80::1'], 'IPv6')]
 
         self.firewall.ipset.assert_has_calls(calls, True)
 
     def test_prepare_port_filter_with_del_member(self):
         self.firewall.sg_rules = self._fake_sg_rule()
-        self.firewall.ipset_chains = {'IPv4fake_sgid': ['10.0.0.2']}
+        self.firewall.ipset_chains = {'NETIPv4fake_sgid': ['10.0.0.2']}
         self.firewall.sg_members = {'fake_sgid': {
             'IPv4': [
                 '10.0.0.1', '10.0.0.3', '10.0.0.4', '10.0.0.5'],
@@ -1317,20 +1322,25 @@ class IptablesFirewallEnhancedIpsetTestCase(BaseIptablesFirewallTestCase):
         port = self._fake_port()
         self.firewall.prepare_port_filter(port)
         calls = [
-            mock.call.add_member_to_ipset_chain('IPv4fake_sgid', '10.0.0.1'),
-            mock.call.add_member_to_ipset_chain('IPv4fake_sgid', '10.0.0.3'),
-            mock.call.add_member_to_ipset_chain('IPv4fake_sgid', '10.0.0.4'),
-            mock.call.add_member_to_ipset_chain('IPv4fake_sgid', '10.0.0.5'),
-            mock.call.del_ipset_chain_member('IPv4fake_sgid', '10.0.0.2'),
-            mock.call.create_ipset_chain('IPv6fake_sgid', 'IPv6'),
+            mock.call.add_member_to_ipset_chain('NETIPv4fake_sgid',
+                                                '10.0.0.1'),
+            mock.call.add_member_to_ipset_chain('NETIPv4fake_sgid',
+                                                '10.0.0.3'),
+            mock.call.add_member_to_ipset_chain('NETIPv4fake_sgid',
+                                                '10.0.0.4'),
+            mock.call.add_member_to_ipset_chain('NETIPv4fake_sgid',
+                                                '10.0.0.5'),
+            mock.call.del_ipset_chain_member('NETIPv4fake_sgid',
+                                             '10.0.0.2'),
+            mock.call.create_ipset_chain('NETIPv6fake_sgid', 'IPv6'),
             mock.call.refresh_ipset_chain_by_name(
-                'IPv6fake_sgid', ['fe80::1'], 'IPv6')]
+                'NETIPv6fake_sgid', ['fe80::1'], 'IPv6')]
 
         self.firewall.ipset.assert_has_calls(calls, True)
 
     def test_prepare_port_filter_change_beyond_9(self):
         self.firewall.sg_rules = self._fake_sg_rule()
-        self.firewall.ipset_chains = {'IPv4fake_sgid': TEST_IP_RANGE[5:]}
+        self.firewall.ipset_chains = {'NETIPv4fake_sgid': TEST_IP_RANGE[5:]}
         self.firewall.sg_members = {'fake_sgid': {
             'IPv4': TEST_IP_RANGE[:5],
             'IPv6': ['fe80::1']}}
@@ -1340,11 +1350,11 @@ class IptablesFirewallEnhancedIpsetTestCase(BaseIptablesFirewallTestCase):
         port = self._fake_port()
         self.firewall.prepare_port_filter(port)
         calls = [
-            mock.call.refresh_ipset_chain_by_name('IPv4fake_sgid',
+            mock.call.refresh_ipset_chain_by_name('NETIPv4fake_sgid',
                                                   TEST_IP_RANGE[:5], 'IPv4'),
-            mock.call.create_ipset_chain('IPv6fake_sgid', 'IPv6'),
+            mock.call.create_ipset_chain('NETIPv6fake_sgid', 'IPv6'),
             mock.call.refresh_ipset_chain_by_name(
-                'IPv6fake_sgid', ['fe80::1'], 'IPv6')]
+                'NETIPv6fake_sgid', ['fe80::1'], 'IPv6')]
 
         self.firewall.ipset.assert_has_calls(calls)
 
@@ -1359,11 +1369,11 @@ class IptablesFirewallEnhancedIpsetTestCase(BaseIptablesFirewallTestCase):
         port = self._fake_port()
         port['security_group_source_groups'].append('fake_sgid2')
         self.firewall.prepare_port_filter(port)
-        calls = [mock.call.create_ipset_chain('IPv4fake_sgid', 'IPv4'),
+        calls = [mock.call.create_ipset_chain('NETIPv4fake_sgid', 'IPv4'),
                  mock.call.refresh_ipset_chain_by_name(
-                     'IPv4fake_sgid', ['10.0.0.1', '10.0.0.2'], 'IPv4'),
-                 mock.call.create_ipset_chain('IPv6fake_sgid', 'IPv6'),
+                     'NETIPv4fake_sgid', ['10.0.0.1', '10.0.0.2'], 'IPv4'),
+                 mock.call.create_ipset_chain('NETIPv6fake_sgid', 'IPv6'),
                  mock.call.refresh_ipset_chain_by_name(
-                     'IPv6fake_sgid', ['fe80::1'], 'IPv6')]
+                     'NETIPv6fake_sgid', ['fe80::1'], 'IPv6')]
 
         self.firewall.ipset.assert_has_calls(calls)
