@@ -115,6 +115,56 @@ class FakeL3Scheduler(l3_agent_scheduler.L3Scheduler):
         pass
 
 
+class FakePortDB(object):
+    def __init__(self, port_list):
+        self._port_list = port_list
+
+    def _get_query_answer(self, port_list, filters):
+        answers = []
+        for port in port_list:
+            matched = True
+            for key, search_values in filters.items():
+                port_value = port.get(key, None)
+                if not port_value:
+                    matched = False
+                    break
+
+                if isinstance(port_value, list):
+                    sub_answers = self._get_query_answer(port_value,
+                                                         search_values)
+                    matched = len(sub_answers) > 0
+                else:
+                    matched = port_value in search_values
+
+                if not matched:
+                    break
+
+            if matched:
+                answers.append(port)
+
+        return answers
+
+    def get_port(self, context, port_id):
+        for port in self._port_list:
+            if port['id'] == port_id:
+                if port['tenant_id'] == context.tenant_id or context.is_admin:
+                    return port
+                break
+
+        return None
+
+    def get_ports(self, context, filters=None):
+        query_filters = dict()
+        if filters:
+            query_filters.update(filters)
+
+        if not context.is_admin:
+            query_filters['tenant_id'] = [context.tenant_id]
+
+        result = self._get_query_answer(self._port_list, query_filters)
+        return result
+
+
 class L3SchedulerBaseTestCase(base.BaseTestCase):
 
     def setUp(self):
@@ -416,18 +466,12 @@ class L3SchedulerTestBaseMixin(object):
         sync_router = {'id': 'foo_router_id',
                        'distributed': True}
         plugin.get_router.return_value = sync_router
-        with contextlib.nested(
-            mock.patch.object(scheduler, 'bind_router'),
-            mock.patch.object(plugin, 'get_snat_bindings', return_value=True)):
+        with mock.patch.object(plugin, 'get_snat_bindings', return_value=True):
                 scheduler._schedule_router(
                     plugin, self.adminContext, 'foo_router_id', None)
         expected_calls = [
             mock.call.get_router(mock.ANY, 'foo_router_id'),
             mock.call.unbind_snat_servicenode(mock.ANY, 'foo_router_id'),
-            mock.call.get_l3_agents_hosting_routers(
-                mock.ANY, ['foo_router_id'], admin_state_up=True),
-            mock.call.get_l3_agents(mock.ANY, active=True),
-            mock.call.get_l3_agent_candidates(mock.ANY, sync_router, [agent]),
         ]
         plugin.assert_has_calls(expected_calls)
 
@@ -442,21 +486,14 @@ class L3SchedulerTestBaseMixin(object):
             }
         }
         plugin.get_router.return_value = sync_router
-        with contextlib.nested(
-            mock.patch.object(scheduler, 'bind_router'),
-            mock.patch.object(
-                plugin, 'get_snat_bindings', return_value=False)
-        ):
+        with mock.patch.object(
+            plugin, 'get_snat_bindings', return_value=False):
                 scheduler._schedule_router(
                     plugin, self.adminContext, 'foo_router_id', None)
         expected_calls = [
             mock.call.get_router(mock.ANY, 'foo_router_id'),
             mock.call.schedule_snat_router(
                 mock.ANY, 'foo_router_id', sync_router),
-            mock.call.get_l3_agents_hosting_routers(
-                mock.ANY, ['foo_router_id'], admin_state_up=True),
-            mock.call.get_l3_agents(mock.ANY, active=True),
-            mock.call.get_l3_agent_candidates(mock.ANY, sync_router, [agent]),
         ]
         plugin.assert_has_calls(expected_calls)
 
@@ -611,13 +648,49 @@ class L3SchedulerTestBaseMixin(object):
                                                     l3_agent, router['id'])
             self.assertFalse(val)
 
+    def test_check_ports_exist_on_l3agent_with_dhcp_enabled_subnets(self):
+        self._register_l3_dvr_agents()
+        router = self._make_router(self.fmt,
+                                   tenant_id=str(uuid.uuid4()),
+                                   name='r2')
+        router['external_gateway_info'] = None
+        router['id'] = str(uuid.uuid4())
+        router['distributed'] = True
+
+        agent_list = [self.l3_dvr_snat_agent]
+        subnet = {'id': str(uuid.uuid4()),
+                  'enable_dhcp': True}
+
+        self.get_subnet_ids_on_router = mock.Mock(
+            return_value=[subnet['id']])
+
+        self.plugin.get_subnet = mock.Mock(return_value=subnet)
+        self.plugin.get_ports = mock.Mock()
+        val = self.check_ports_exist_on_l3agent(
+            self.adminContext, agent_list[0], router['id'])
+        self.assertTrue(val)
+        self.assertFalse(self.plugin.get_ports.called)
+
+    def test_check_ports_exist_on_l3agent_if_no_subnets_then_return(self):
+        l3_agent, router = self._prepare_check_ports_exist_tests()
+        with mock.patch.object(manager.NeutronManager,
+                               'get_plugin') as getp:
+            getp.return_value = self.plugin
+            # no subnets and operation is remove_router_interface,
+            # so return immediately without calling get_ports
+            self.check_ports_exist_on_l3agent(self.adminContext,
+                                          l3_agent, router['id'])
+        self.assertFalse(self.plugin.get_ports.called)
+
     def test_check_ports_exist_on_l3agent_no_subnet_match(self):
         l3_agent, router = self._prepare_check_ports_exist_tests()
         with mock.patch.object(manager.NeutronManager,
                                'get_plugin') as getp:
             getp.return_value = self.plugin
             # no matching subnet
-            self.get_subnet_ids_on_router.return_value = [str(uuid.uuid4())]
+            subnet = {'id': str(uuid.uuid4()), 'enable_dhcp': False}
+            self.get_subnet_ids_on_router.return_value = [subnet['id']]
+            self.plugin.get_subnet = mock.Mock(return_value=subnet)
             val = self.check_ports_exist_on_l3agent(self.adminContext,
                                                     l3_agent, router['id'])
             self.assertFalse(val)
@@ -632,9 +705,12 @@ class L3SchedulerTestBaseMixin(object):
                     'binding:host_id': HOST,
                     'device_owner': 'compute:',
                     'id': 1234}
+            subnet = {'id': str(uuid.uuid4()),
+                      'enable_dhcp': False}
             self.plugin.get_ports.return_value = [port]
-            self.plugin.get_subnet_ids_on_router = mock.Mock(
+            self.get_subnet_ids_on_router = mock.Mock(
                 return_value=[port['subnet_id']])
+            self.plugin.get_subnet = mock.Mock(return_value=subnet)
             val = self.check_ports_exist_on_l3agent(self.adminContext,
                                                     l3_agent, router['id'])
             self.assertTrue(val)
@@ -934,6 +1010,195 @@ class L3DvrSchedulerTestCase(testlib_api.SqlTestCase,
         }
         self._test_dvr_serviced_port_exists_on_subnet(port=vip_port)
 
+    def _create_port(self, port_name, tenant_id, host, subnet_id, ip_address,
+                     status='ACTIVE',
+                     device_owner='compute:nova'):
+        return {
+            'id': port_name + '-port-id',
+            'tenant_id': tenant_id,
+            'device_id': port_name,
+            'device_owner': device_owner,
+            'status': status,
+            'binding:host_id': host,
+            'fixed_ips': [
+                {
+                    'subnet_id': subnet_id,
+                    'ip_address': ip_address
+                }
+            ]
+        }
+
+    def test_dvr_deletens_if_no_port_no_routers(self):
+        # Delete a vm port, the port subnet has no router interface.
+        vm_tenant_id = 'tenant-1'
+        my_context = q_context.Context('user-1', vm_tenant_id, is_admin=False)
+        vm_port_host = 'compute-node-1'
+
+        vm_port = self._create_port(
+            'deleted-vm', vm_tenant_id, vm_port_host,
+            'shared-subnet', '10.10.10.3',
+            status='INACTIVE')
+
+        vm_port_id = vm_port['id']
+        fakePortDB = FakePortDB([vm_port])
+
+        with contextlib.nested(
+            mock.patch.object(my_context, 'elevated',
+                              return_value=self.adminContext),
+            mock.patch('neutron.plugins.ml2.db.'
+                       'get_port_binding_host', return_value=vm_port_host),
+            mock.patch('neutron.db.db_base_plugin_v2.NeutronDbPluginV2.'
+                       'get_ports', side_effect=fakePortDB.get_ports),
+            mock.patch('neutron.db.db_base_plugin_v2.NeutronDbPluginV2.'
+                       'get_port', return_value=vm_port)) as (
+                _, mock_get_port_binding_host, _, _):
+
+            routers = self.dut.dvr_deletens_if_no_port(my_context, vm_port_id)
+            self.assertEqual([], routers)
+            mock_get_port_binding_host.assert_called_once_with(vm_port_id)
+
+    def test_dvr_deletens_if_no_ports_no_removeable_routers(self):
+        # A VM port is deleted, but the router can't be unscheduled from the
+        # compute node because there is another VM port present.
+        vm_tenant_id = 'tenant-1'
+        my_context = q_context.Context('user-1', vm_tenant_id, is_admin=False)
+        shared_subnet_id = '80947d4a-fbc8-484b-9f92-623a6bfcf3e0',
+        vm_port_host = 'compute-node-1'
+
+        dvr_port = self._create_port(
+            'dvr-router', 'admin-tenant', vm_port_host,
+            shared_subnet_id, '10.10.10.1',
+            device_owner=constants.DEVICE_OWNER_DVR_INTERFACE)
+
+        deleted_vm_port = self._create_port(
+            'deleted-vm', vm_tenant_id, vm_port_host,
+            shared_subnet_id, '10.10.10.3',
+            status='INACTIVE')
+        deleted_vm_port_id = deleted_vm_port['id']
+
+        running_vm_port = self._create_port(
+            'running-vn', 'tenant-2', vm_port_host,
+            shared_subnet_id, '10.10.10.33')
+
+        fakePortDB = FakePortDB([running_vm_port, deleted_vm_port, dvr_port])
+
+        vm_port_binding = {
+            'port_id': deleted_vm_port_id,
+            'host': vm_port_host
+        }
+
+        with contextlib.nested(
+            mock.patch.object(my_context, 'elevated',
+                              return_value=self.adminContext),
+            mock.patch('neutron.plugins.ml2.db.get_port_binding_host',
+                       return_value=vm_port_host),
+            mock.patch('neutron.db.db_base_plugin_v2.NeutronDbPluginV2.'
+                       'get_port', side_effect=fakePortDB.get_port),
+            mock.patch('neutron.db.db_base_plugin_v2.NeutronDbPluginV2.'
+                       'get_ports', side_effect=fakePortDB.get_ports),
+            mock.patch('neutron.plugins.ml2.db.get_dvr_port_binding_by_host',
+                       return_value=vm_port_binding)) as (_,
+                mock_get_port_binding_host, _,
+                mock_get_ports,
+                mock_get_dvr_port_binding_by_host):
+
+            routers = self.dut.dvr_deletens_if_no_port(
+                my_context, deleted_vm_port_id)
+            self.assertEqual([], routers)
+
+            mock_get_port_binding_host.assert_called_once_with(
+                deleted_vm_port_id)
+            self.assertTrue(mock_get_ports.called)
+            self.assertFalse(mock_get_dvr_port_binding_by_host.called)
+
+    def _test_dvr_deletens_if_no_ports_delete_routers(self,
+                                                      vm_tenant,
+                                                      router_tenant):
+        class FakeAgent(object):
+            def __init__(self, id, host, agent_type):
+                self.id = id
+                self.host = host
+                self.agent_type = agent_type
+
+        my_context = q_context.Context('user-1', vm_tenant, is_admin=False)
+        shared_subnet_id = '80947d4a-fbc8-484b-9f92-623a6bfcf3e0',
+        vm_port_host = 'compute-node-1'
+
+        router_id = 'dvr-router'
+        dvr_port = self._create_port(
+            router_id, router_tenant, vm_port_host,
+            shared_subnet_id, '10.10.10.1',
+            device_owner=constants.DEVICE_OWNER_DVR_INTERFACE)
+        dvr_port_id = dvr_port['id']
+
+        deleted_vm_port = self._create_port(
+            'deleted-vm', vm_tenant, vm_port_host,
+            shared_subnet_id, '10.10.10.3',
+            status='INACTIVE')
+        deleted_vm_port_id = deleted_vm_port['id']
+
+        running_vm_port = self._create_port(
+             'running-vn', vm_tenant, 'compute-node-2',
+             shared_subnet_id, '10.10.10.33')
+
+        fakePortDB = FakePortDB([running_vm_port, dvr_port, deleted_vm_port])
+
+        dvr_port_binding = {
+            'port_id': dvr_port_id, 'host': vm_port_host
+        }
+
+        agent_id = 'l3-agent-on-compute-node-1'
+        l3_agent_on_vm_host = FakeAgent(agent_id,
+                                        vm_port_host,
+                                        constants.AGENT_TYPE_L3)
+
+        with contextlib.nested(
+            mock.patch.object(my_context, 'elevated',
+                              return_value=self.adminContext),
+            mock.patch('neutron.plugins.ml2.db.get_port_binding_host',
+                       return_value=vm_port_host),
+            mock.patch('neutron.db.db_base_plugin_v2.NeutronDbPluginV2.'
+                       'get_port', side_effect=fakePortDB.get_port),
+            mock.patch('neutron.db.db_base_plugin_v2.NeutronDbPluginV2.'
+                       'get_ports', side_effect=fakePortDB.get_ports),
+            mock.patch('neutron.plugins.ml2.db.get_dvr_port_binding_by_host',
+                       return_value=dvr_port_binding),
+            mock.patch('neutron.db.agents_db.AgentDbMixin.'
+                       '_get_agent_by_type_and_host',
+                       return_value=l3_agent_on_vm_host)) as (_,
+                mock_get_port_binding_host, _,
+                mock_get_ports,
+                mock_get_dvr_port_binding_by_host,
+                mock__get_agent_by_type_and_host):
+
+            routers = self.dut.dvr_deletens_if_no_port(
+                my_context, deleted_vm_port_id)
+
+            expected_router = {
+                'router_id': router_id,
+                'host': vm_port_host,
+                'agent_id': agent_id
+            }
+            self.assertEqual([expected_router], routers)
+
+            mock_get_port_binding_host.assert_called_once_with(
+                deleted_vm_port_id)
+            self.assertTrue(mock_get_ports.called)
+            mock_get_dvr_port_binding_by_host.assert_called_once_with(
+                my_context.session, dvr_port_id, vm_port_host)
+
+    def test_dvr_deletens_if_no_ports_delete_admin_routers(self):
+        # test to see whether the last VM using a router created
+        # by the admin will be unscheduled on the compute node
+        self._test_dvr_deletens_if_no_ports_delete_routers(
+            'tenant-1', 'admin-tenant')
+
+    def test_dvr_deletens_if_no_ports_delete_tenant_routers(self):
+        # test to see whether the last VM using a tenant's private
+        # router will be unscheduled on the compute node
+        self._test_dvr_deletens_if_no_ports_delete_routers(
+            'tenant-1', 'tenant-1')
+
     def test_dvr_serviced_dhcp_port_exists_on_subnet(self):
         dhcp_port = {
                 'id': 'dhcp-port1',
@@ -964,6 +1229,21 @@ class L3DvrSchedulerTestCase(testlib_api.SqlTestCase,
         }
         return agent, router
 
+    def test_schedule_snat_router_return_value(self):
+        agent, router = self._prepare_schedule_snat_tests()
+        with contextlib.nested(
+            mock.patch.object(self.dut, 'get_l3_agents'),
+            mock.patch.object(self.dut, 'get_snat_candidates'),
+            mock.patch.object(self.dut, 'bind_snat_servicenode'),
+            mock.patch.object(self.dut, 'bind_dvr_router_servicenode')
+        ) as (mock_gl3, mock_snat_canidates, mock_bind_snat, mock_bind_dvr):
+            mock_snat_canidates.return_value = [agent]
+            mock_bind_snat.return_value = [agent]
+            mock_bind_dvr.return_value = [agent]
+            chosen_agent = self.dut.schedule_snat_router(
+                self.adminContext, 'foo_router_id', router)
+        self.assertEqual(chosen_agent, [agent])
+
     def test_schedule_router_unbind_snat_servicenode_negativetest(self):
         router = {
             'id': 'foo_router_id',
