@@ -815,8 +815,7 @@ class TestDnsmasq(TestBase):
             '--dhcp-hostsfile=/dhcp/%s/host' % network.id,
             '--addn-hosts=/dhcp/%s/addn_hosts' % network.id,
             '--dhcp-optsfile=/dhcp/%s/opts' % network.id,
-            '--leasefile-ro',
-            '--dhcp-authoritative']
+            '--dhcp-leasefile=/dhcp/%s/leases' % network.id]
 
         seconds = ''
         if lease_duration == -1:
@@ -889,7 +888,8 @@ class TestDnsmasq(TestBase):
         self.conf.set_override('dhcp_domain', '')
         self._test_spawn(['--conf-file='])
         self.safe.assert_has_calls([mock.call(exp_host_name, exp_host_data),
-                                    mock.call(exp_addn_name, exp_addn_data)])
+                                    mock.call(exp_addn_name, exp_addn_data),
+                                    mock.call(mock.ANY, mock.ANY)])
 
     def test_spawn_no_dhcp_range(self):
         network = FakeV6Network()
@@ -918,6 +918,35 @@ class TestDnsmasq(TestBase):
             network=FakeV4Network(),
             max_leases=256)
 
+    def _test_output_init_lease_file(self, timestamp):
+        expected = [
+            '00:00:80:aa:bb:cc 192.168.0.2 * *',
+            '00:00:f3:aa:bb:cc [fdca:3ba5:a17a:4ba3::2] * *',
+            '00:00:0f:aa:bb:cc 192.168.0.3 * *',
+            '00:00:0f:aa:bb:cc [fdca:3ba5:a17a:4ba3::3] * *',
+            '00:00:0f:rr:rr:rr 192.168.0.1 * *\n']
+        expected = "\n".join(['%s %s' % (timestamp, l) for l in expected])
+        with mock.patch.object(dhcp.Dnsmasq, 'get_conf_file_name') as conf_fn:
+            conf_fn.return_value = '/foo/leases'
+            dm = dhcp.Dnsmasq(self.conf, FakeDualNetwork(),
+                              version=dhcp.Dnsmasq.MINIMUM_VERSION)
+            dm._output_init_lease_file()
+        self.safe.assert_called_once_with('/foo/leases', expected)
+
+    @mock.patch('time.time')
+    def test_output_init_lease_file(self, tmock):
+        self.conf.set_override('dhcp_lease_duration', 500)
+        tmock.return_value = 1000000
+        # lease duration should be added to current time
+        timestamp = 1000000 + 500
+        self._test_output_init_lease_file(timestamp)
+
+    def test_output_init_lease_file_infinite_duration(self):
+        self.conf.set_override('dhcp_lease_duration', -1)
+        # when duration is infinite, lease db timestamp should be 0
+        timestamp = 0
+        self._test_output_init_lease_file(timestamp)
+
     def test_output_opts_file(self):
         fake_v6 = '2001:0200:feed:7ac0::1'
         expected = (
@@ -1427,6 +1456,17 @@ tag:tag0,option:router""".lstrip()
                                 float(2.66))
             self.assertTrue(warning.called)
 
+    def test__output_hosts_file_log_only_twice(self):
+        dm = dhcp.Dnsmasq(self.conf, FakeDualStackNetworkSingleDHCP(),
+                          version=dhcp.Dnsmasq.MINIMUM_VERSION)
+        with mock.patch.object(dhcp.LOG, 'process') as process:
+            process.return_value = ('fake_message', {})
+            dm._output_hosts_file()
+        # The method logs twice, at the start of and the end. There should be
+        # no other logs, no matter how many hosts there are to dump in the
+        # file.
+        self.assertEqual(2, process.call_count)
+
     def test_only_populates_dhcp_enabled_subnets(self):
         exp_host_name = '/dhcp/eeeeeeee-eeee-eeee-eeee-eeeeeeeeeeee/host'
         exp_host_data = ('00:00:80:aa:bb:cc,host-192-168-0-2.openstacklocal,'
@@ -1478,3 +1518,26 @@ tag:tag0,option:router""".lstrip()
         self.conf.set_override('enable_metadata_network', True)
         self.assertTrue(dhcp.Dnsmasq.should_enable_metadata(
             self.conf, FakeV4MetadataNetwork()))
+
+    def _test_output_opts_file(self, expected, network, ipm_retval=None):
+        with mock.patch.object(dhcp.Dnsmasq, 'get_conf_file_name') as conf_fn:
+            conf_fn.return_value = '/foo/opts'
+            dm = dhcp.Dnsmasq(self.conf, network)
+            if ipm_retval:
+                with mock.patch.object(
+                        dm, '_make_subnet_interface_ip_map') as ipm:
+                    ipm.return_value = ipm_retval
+                    dm._output_opts_file()
+                    self.assertTrue(ipm.called)
+            else:
+                dm._output_opts_file()
+        self.safe.assert_called_once_with('/foo/opts', expected)
+
+    def test_output_opts_file_ipv6_address_mode_unset(self):
+        fake_v6 = '2001:0200:feed:7ac0::1'
+        expected = (
+            'tag:tag0,option6:dns-server,%s\n'
+            'tag:tag0,option6:domain-search,openstacklocal').lstrip() % (
+                '[' + fake_v6 + ']')
+
+        self._test_output_opts_file(expected, FakeV6Network())
