@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright (c) 2012 OpenStack Foundation.
 # All Rights Reserved.
 #
@@ -15,31 +13,22 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import os
 import types
 
 import fixtures
 
 from oslo.config import cfg
 
-from neutron.common import config
-from neutron.manager import NeutronManager
-from neutron.manager import validate_post_plugin_load
-from neutron.manager import validate_pre_plugin_load
+from neutron import manager
 from neutron.openstack.common import log as logging
 from neutron.plugins.common import constants
 from neutron.tests import base
 from neutron.tests.unit import dummy_plugin
+from neutron.tests.unit import testlib_plugin
 
 
 LOG = logging.getLogger(__name__)
 DB_PLUGIN_KLASS = 'neutron.db.db_base_plugin_v2.NeutronDbPluginV2'
-ROOTDIR = os.path.dirname(os.path.dirname(__file__))
-ETCDIR = os.path.join(ROOTDIR, 'etc')
-
-
-def etcdir(*p):
-    return os.path.join(ETCDIR, *p)
 
 
 class MultiServiceCorePlugin(object):
@@ -51,13 +40,12 @@ class CorePluginWithAgentNotifiers(object):
                        'dhcp': 'dhcp_agent_notifier'}
 
 
-class NeutronManagerTestCase(base.BaseTestCase):
+class NeutronManagerTestCase(base.BaseTestCase,
+                             testlib_plugin.PluginSetupHelper):
 
     def setUp(self):
         super(NeutronManagerTestCase, self).setUp()
-        args = ['--config-file', etcdir('neutron.conf.test')]
-        # If test_config specifies some config-file, use it, as well
-        config.parse(args=args)
+        self.config_parse()
         self.setup_coreplugin()
         self.useFixture(
             fixtures.MonkeyPatch('neutron.manager.NeutronManager._instance'))
@@ -67,23 +55,21 @@ class NeutronManagerTestCase(base.BaseTestCase):
         cfg.CONF.set_override("service_plugins",
                               ["neutron.tests.unit.dummy_plugin."
                                "DummyServicePlugin"])
-        mgr = NeutronManager.get_instance()
+        mgr = manager.NeutronManager.get_instance()
         plugin = mgr.get_service_plugins()[constants.DUMMY]
 
-        self.assertTrue(
-            isinstance(plugin,
-                       (dummy_plugin.DummyServicePlugin, types.ClassType)),
+        self.assertIsInstance(
+            plugin, (dummy_plugin.DummyServicePlugin, types.ClassType),
             "loaded plugin should be of type neutronDummyPlugin")
 
     def test_service_plugin_by_name_is_loaded(self):
         cfg.CONF.set_override("core_plugin", DB_PLUGIN_KLASS)
         cfg.CONF.set_override("service_plugins", ["dummy"])
-        mgr = NeutronManager.get_instance()
+        mgr = manager.NeutronManager.get_instance()
         plugin = mgr.get_service_plugins()[constants.DUMMY]
 
-        self.assertTrue(
-            isinstance(plugin,
-                       (dummy_plugin.DummyServicePlugin, types.ClassType)),
+        self.assertIsInstance(
+            plugin, (dummy_plugin.DummyServicePlugin, types.ClassType),
             "loaded plugin should be of type neutronDummyPlugin")
 
     def test_multiple_plugins_specified_for_service_type(self):
@@ -93,19 +79,20 @@ class NeutronManagerTestCase(base.BaseTestCase):
                                "neutron.tests.unit.dummy_plugin."
                                "DummyServicePlugin"])
         cfg.CONF.set_override("core_plugin", DB_PLUGIN_KLASS)
-        self.assertRaises(ValueError, NeutronManager.get_instance)
+        e = self.assertRaises(ValueError, manager.NeutronManager.get_instance)
+        self.assertIn(constants.DUMMY, e.message)
 
     def test_multiple_plugins_by_name_specified_for_service_type(self):
         cfg.CONF.set_override("service_plugins", ["dummy", "dummy"])
         cfg.CONF.set_override("core_plugin", DB_PLUGIN_KLASS)
-        self.assertRaises(ValueError, NeutronManager.get_instance)
+        self.assertRaises(ValueError, manager.NeutronManager.get_instance)
 
     def test_multiple_plugins_mixed_specified_for_service_type(self):
         cfg.CONF.set_override("service_plugins",
                               ["neutron.tests.unit.dummy_plugin."
                                "DummyServicePlugin", "dummy"])
         cfg.CONF.set_override("core_plugin", DB_PLUGIN_KLASS)
-        self.assertRaises(ValueError, NeutronManager.get_instance)
+        self.assertRaises(ValueError, manager.NeutronManager.get_instance)
 
     def test_service_plugin_conflicts_with_core_plugin(self):
         cfg.CONF.set_override("service_plugins",
@@ -114,13 +101,14 @@ class NeutronManagerTestCase(base.BaseTestCase):
         cfg.CONF.set_override("core_plugin",
                               "neutron.tests.unit.test_neutron_manager."
                               "MultiServiceCorePlugin")
-        self.assertRaises(ValueError, NeutronManager.get_instance)
+        e = self.assertRaises(ValueError, manager.NeutronManager.get_instance)
+        self.assertIn(constants.DUMMY, e.message)
 
     def test_core_plugin_supports_services(self):
         cfg.CONF.set_override("core_plugin",
                               "neutron.tests.unit.test_neutron_manager."
                               "MultiServiceCorePlugin")
-        mgr = NeutronManager.get_instance()
+        mgr = manager.NeutronManager.get_instance()
         svc_plugins = mgr.get_service_plugins()
         self.assertEqual(3, len(svc_plugins))
         self.assertIn(constants.CORE, svc_plugins.keys())
@@ -131,18 +119,18 @@ class NeutronManagerTestCase(base.BaseTestCase):
         cfg.CONF.import_opt('dhcp_agents_per_network',
                             'neutron.db.agentschedulers_db')
 
-        self.assertIsNone(validate_post_plugin_load())
+        self.assertIsNone(manager.validate_post_plugin_load())
         cfg.CONF.set_override('dhcp_agents_per_network', 2)
-        self.assertIsNone(validate_post_plugin_load())
+        self.assertIsNone(manager.validate_post_plugin_load())
         cfg.CONF.set_override('dhcp_agents_per_network', 0)
-        self.assertIsNotNone(validate_post_plugin_load())
+        self.assertIsNotNone(manager.validate_post_plugin_load())
         cfg.CONF.set_override('dhcp_agents_per_network', -1)
-        self.assertIsNotNone(validate_post_plugin_load())
+        self.assertIsNotNone(manager.validate_post_plugin_load())
 
     def test_pre_plugin_validation(self):
-        self.assertIsNotNone(validate_pre_plugin_load())
+        self.assertIsNotNone(manager.validate_pre_plugin_load())
         cfg.CONF.set_override('core_plugin', 'dummy.plugin')
-        self.assertIsNone(validate_pre_plugin_load())
+        self.assertIsNone(manager.validate_pre_plugin_load())
 
     def test_manager_gathers_agent_notifiers_from_service_plugins(self):
         cfg.CONF.set_override("service_plugins",
@@ -154,5 +142,5 @@ class NeutronManagerTestCase(base.BaseTestCase):
         expected = {'l3': 'l3_agent_notifier',
                     'dhcp': 'dhcp_agent_notifier',
                     'dummy': 'dummy_agent_notifier'}
-        core_plugin = NeutronManager.get_plugin()
+        core_plugin = manager.NeutronManager.get_plugin()
         self.assertEqual(expected, core_plugin.agent_notifiers)
