@@ -11,12 +11,9 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
-# @author: linb, VMware
 
 import mock
 
-from neutron.common import config as n_config
 from neutron import context
 from neutron.openstack.common import uuidutils
 from neutron.plugins.vmware.dbexts import vcns_db
@@ -24,8 +21,7 @@ from neutron.plugins.vmware.vshield.common import exceptions as vcns_exc
 from neutron.plugins.vmware.vshield import vcns_driver
 from neutron.services.loadbalancer import constants as lb_constants
 from neutron.tests.unit.db.loadbalancer import test_db_loadbalancer
-from neutron.tests.unit.vmware import get_fake_conf
-from neutron.tests.unit.vmware import VCNS_NAME
+from neutron.tests.unit import vmware
 from neutron.tests.unit.vmware.vshield import fake_vcns
 
 _uuid = uuidutils.generate_uuid
@@ -36,7 +32,7 @@ POOL_MAP_INFO = {
     'edge_id': VSE_ID,
     'pool_vseid': 'pool-1'}
 
-VCNS_CONFIG_FILE = get_fake_conf("vcns.ini.test")
+VCNS_CONFIG_FILE = vmware.get_fake_conf("vcns.ini.test")
 
 
 class VcnsDriverTestCase(test_db_loadbalancer.LoadBalancerPluginDbTestCase):
@@ -78,10 +74,10 @@ class VcnsDriverTestCase(test_db_loadbalancer.LoadBalancerPluginDbTestCase):
 
     def setUp(self):
 
-        n_config.parse(['--config-file', VCNS_CONFIG_FILE])
+        self.config_parse(args=['--config-file', VCNS_CONFIG_FILE])
         # mock vcns
         self.fc2 = fake_vcns.FakeVcns(unique_router_name=False)
-        self.mock_vcns = mock.patch(VCNS_NAME, autospec=True)
+        self.mock_vcns = mock.patch(vmware.VCNS_NAME, autospec=True)
         self.vcns_loadbalancer_patch()
 
         self.driver = vcns_driver.VcnsDriver(mock.Mock())
@@ -98,7 +94,7 @@ class TestEdgeLbDriver(VcnsDriverTestCase):
 
     def test_create_and_get_vip(self):
         ctx = context.get_admin_context()
-        with self.pool(no_delete=True) as pool:
+        with self.pool(do_delete=False) as pool:
             self.pool_id = pool['pool']['id']
             POOL_MAP_INFO['pool_id'] = pool['pool']['id']
             vcns_db.add_vcns_edge_pool_binding(ctx.session, POOL_MAP_INFO)
@@ -111,7 +107,7 @@ class TestEdgeLbDriver(VcnsDriverTestCase):
 
     def test_create_two_vips_with_same_name(self):
         ctx = context.get_admin_context()
-        with self.pool(no_delete=True) as pool:
+        with self.pool(do_delete=False) as pool:
             self.pool_id = pool['pool']['id']
             POOL_MAP_INFO['pool_id'] = pool['pool']['id']
             vcns_db.add_vcns_edge_pool_binding(ctx.session, POOL_MAP_INFO)
@@ -212,7 +208,7 @@ class TestEdgeLbDriver(VcnsDriverTestCase):
 
     def test_update_vip(self):
         ctx = context.get_admin_context()
-        with self.pool(no_delete=True) as pool:
+        with self.pool(do_delete=False) as pool:
             self.pool_id = pool['pool']['id']
             POOL_MAP_INFO['pool_id'] = pool['pool']['id']
             vcns_db.add_vcns_edge_pool_binding(ctx.session, POOL_MAP_INFO)
@@ -235,7 +231,7 @@ class TestEdgeLbDriver(VcnsDriverTestCase):
 
     def test_delete_vip(self):
         ctx = context.get_admin_context()
-        with self.pool(no_delete=True) as pool:
+        with self.pool(do_delete=False) as pool:
             self.pool_id = pool['pool']['id']
             POOL_MAP_INFO['pool_id'] = pool['pool']['id']
             vcns_db.add_vcns_edge_pool_binding(ctx.session, POOL_MAP_INFO)
@@ -251,7 +247,7 @@ class TestEdgeLbDriver(VcnsDriverTestCase):
     #Test Pool Operation
     def test_create_and_get_pool(self):
         ctx = context.get_admin_context()
-        with self.pool(no_delete=True) as p:
+        with self.pool(do_delete=False) as p:
             self.pool_id = p['pool']['id']
             pool_create = p['pool']
             self.driver.create_pool(ctx, VSE_ID, pool_create, [])
@@ -261,7 +257,7 @@ class TestEdgeLbDriver(VcnsDriverTestCase):
 
     def test_create_two_pools_with_same_name(self):
         ctx = context.get_admin_context()
-        with self.pool(no_delete=True) as p:
+        with self.pool(do_delete=False) as p:
             self.pool_id = p['pool']['id']
             pool_create = p['pool']
             self.driver.create_pool(ctx, VSE_ID, pool_create, [])
@@ -271,7 +267,7 @@ class TestEdgeLbDriver(VcnsDriverTestCase):
 
     def test_update_pool(self):
         ctx = context.get_admin_context()
-        with self.pool(no_delete=True) as p:
+        with self.pool(do_delete=False) as p:
             self.pool_id = p['pool']['id']
             pool_create = p['pool']
             self.driver.create_pool(ctx, VSE_ID, pool_create, [])
@@ -288,7 +284,7 @@ class TestEdgeLbDriver(VcnsDriverTestCase):
 
     def test_delete_pool(self):
         ctx = context.get_admin_context()
-        with self.pool(no_delete=True) as p:
+        with self.pool(do_delete=False) as p:
             self.pool_id = p['pool']['id']
             pool_create = p['pool']
             self.driver.create_pool(ctx, VSE_ID, pool_create, [])
@@ -301,7 +297,7 @@ class TestEdgeLbDriver(VcnsDriverTestCase):
 
     def test_create_and_get_monitor(self):
         ctx = context.get_admin_context()
-        with self.health_monitor(no_delete=True) as m:
+        with self.health_monitor(do_delete=False) as m:
             monitor_create = m['health_monitor']
             self.driver.create_health_monitor(ctx, VSE_ID, monitor_create)
             monitor_get = self.driver.get_health_monitor(
@@ -311,7 +307,7 @@ class TestEdgeLbDriver(VcnsDriverTestCase):
 
     def test_update_health_monitor(self):
         ctx = context.get_admin_context()
-        with self.health_monitor(no_delete=True) as m:
+        with self.health_monitor(do_delete=False) as m:
             monitor_create = m['health_monitor']
             self.driver.create_health_monitor(
                 ctx, VSE_ID, monitor_create)
@@ -330,7 +326,7 @@ class TestEdgeLbDriver(VcnsDriverTestCase):
 
     def test_delete_health_monitor(self):
         ctx = context.get_admin_context()
-        with self.health_monitor(no_delete=True) as m:
+        with self.health_monitor(do_delete=False) as m:
             monitor_create = m['health_monitor']
             self.driver.create_health_monitor(ctx, VSE_ID, monitor_create)
             self.driver.delete_health_monitor(
