@@ -16,19 +16,15 @@
 from eventlet import greenthread
 import mock
 
-from neutron.common import config as n_config
 from neutron.plugins.vmware.vshield.common import constants as vcns_const
-from neutron.plugins.vmware.vshield.common.constants import RouterStatus
-from neutron.plugins.vmware.vshield.tasks.constants import TaskState
-from neutron.plugins.vmware.vshield.tasks.constants import TaskStatus
+from neutron.plugins.vmware.vshield.tasks import constants as ts_const
 from neutron.plugins.vmware.vshield.tasks import tasks as ts
 from neutron.plugins.vmware.vshield import vcns_driver
 from neutron.tests import base
-from neutron.tests.unit.vmware import get_fake_conf
-from neutron.tests.unit.vmware import VCNS_NAME
+from neutron.tests.unit import vmware
 from neutron.tests.unit.vmware.vshield import fake_vcns
 
-VCNS_CONFIG_FILE = get_fake_conf("vcns.ini.test")
+VCNS_CONFIG_FILE = vmware.get_fake_conf("vcns.ini.test")
 
 ts.TaskManager.set_default_interval(100)
 
@@ -68,12 +64,12 @@ class VcnsDriverTaskManagerTestCase(base.BaseTestCase):
 
         def _exec(task):
             if not _check_state(task, 1):
-                return TaskStatus.ERROR
+                return ts_const.TaskStatus.ERROR
 
             if task.userdata['sync_exec']:
-                return TaskStatus.COMPLETED
+                return ts_const.TaskStatus.COMPLETED
             else:
-                return TaskStatus.PENDING
+                return ts_const.TaskStatus.PENDING
 
         def _status(task):
             if task.userdata['sync_exec']:
@@ -82,10 +78,10 @@ class VcnsDriverTaskManagerTestCase(base.BaseTestCase):
             state = task.userdata['state']
             if state == 3:
                 _check_state(task, 3)
-                return TaskStatus.PENDING
+                return ts_const.TaskStatus.PENDING
             else:
                 _check_state(task, 4)
-                return TaskStatus.COMPLETED
+                return ts_const.TaskStatus.COMPLETED
 
         def _result(task):
             if task.userdata['sync_exec']:
@@ -123,7 +119,7 @@ class VcnsDriverTaskManagerTestCase(base.BaseTestCase):
 
         self.manager.add(task)
 
-        task.wait(TaskState.RESULT)
+        task.wait(ts_const.TaskState.RESULT)
 
         self.assertTrue(userdata['result'])
 
@@ -140,10 +136,10 @@ class VcnsDriverTaskManagerTestCase(base.BaseTestCase):
 
         def _exec(task):
             task.userdata['executed'] = True
-            return TaskStatus.PENDING
+            return ts_const.TaskStatus.PENDING
 
         def _status(task):
-            return TaskStatus.COMPLETED
+            return ts_const.TaskStatus.COMPLETED
 
         def _result(task):
             next_task = task.userdata.get('next')
@@ -168,7 +164,7 @@ class VcnsDriverTaskManagerTestCase(base.BaseTestCase):
         for task in tasks:
             self.manager.add(task)
 
-        last_task.wait(TaskState.RESULT)
+        last_task.wait(ts_const.TaskState.RESULT)
 
         for task in tasks:
             self.assertTrue(task.userdata['result'])
@@ -178,17 +174,17 @@ class VcnsDriverTaskManagerTestCase(base.BaseTestCase):
 
         def _exec(task):
             task.userdata['executed'] = True
-            return TaskStatus.PENDING
+            return ts_const.TaskStatus.PENDING
 
         def _status(task):
             for t in tasks:
                 if not t.userdata.get('executed'):
                     t.userdata['resut'] = False
-            return TaskStatus.COMPLETED
+            return ts_const.TaskStatus.COMPLETED
 
         def _result(task):
             if (task.userdata.get('result') is None and
-                task.status == TaskStatus.COMPLETED):
+                task.status == ts_const.TaskStatus.COMPLETED):
                 task.userdata['result'] = True
             else:
                 task.userdata['result'] = False
@@ -201,7 +197,7 @@ class VcnsDriverTaskManagerTestCase(base.BaseTestCase):
             self.manager.add(task)
 
         for task in tasks:
-            task.wait(TaskState.RESULT)
+            task.wait(ts_const.TaskState.RESULT)
             self.assertTrue(task.userdata['result'])
 
     def _test_task_manager_stop(self, exec_wait=False, result_wait=False,
@@ -209,11 +205,11 @@ class VcnsDriverTaskManagerTestCase(base.BaseTestCase):
         def _exec(task):
             if exec_wait:
                 greenthread.sleep(0.01)
-            return TaskStatus.PENDING
+            return ts_const.TaskStatus.PENDING
 
         def _status(task):
             greenthread.sleep(0.01)
-            return TaskStatus.PENDING
+            return ts_const.TaskStatus.PENDING
 
         def _result(task):
             if result_wait:
@@ -245,7 +241,7 @@ class VcnsDriverTaskManagerTestCase(base.BaseTestCase):
 
         for res, tasks in alltasks.iteritems():
             for task in tasks:
-                self.assertEqual(task.status, TaskStatus.ABORT)
+                self.assertEqual(task.status, ts_const.TaskStatus.ABORT)
 
     def test_task_manager_stop_1(self):
         self._test_task_manager_stop(True, True, 0)
@@ -265,7 +261,7 @@ class VcnsDriverTaskManagerTestCase(base.BaseTestCase):
             while not task.userdata['tested']:
                 greenthread.sleep(0)
             task.userdata['executing'] = False
-            return TaskStatus.COMPLETED
+            return ts_const.TaskStatus.COMPLETED
 
         userdata = {
             'executing': False,
@@ -315,14 +311,13 @@ class VcnsDriverTestCase(base.BaseTestCase):
     def setUp(self):
         super(VcnsDriverTestCase, self).setUp()
 
-        n_config.parse(['--config-file', VCNS_CONFIG_FILE])
+        self.config_parse(args=['--config-file', VCNS_CONFIG_FILE])
 
         self.fc = fake_vcns.FakeVcns()
-        self.mock_vcns = mock.patch(VCNS_NAME, autospec=True)
+        self.mock_vcns = mock.patch(vmware.VCNS_NAME, autospec=True)
         self.vcns_patch()
 
         self.addCleanup(self.fc.reset_all)
-        self.addCleanup(self.mock_vcns.stop)
 
         self.vcns_driver = vcns_driver.VcnsDriver(self)
 
@@ -340,46 +335,46 @@ class VcnsDriverTestCase(base.BaseTestCase):
         task = self.vcns_driver.deploy_edge(
             'router-id', 'myedge', 'internal-network', {}, wait_for_exec=True)
         self.assertEqual(self.edge_id, 'edge-1')
-        task.wait(TaskState.RESULT)
+        task.wait(ts_const.TaskState.RESULT)
         return task
 
     def edge_deploy_started(self, task):
         self.edge_id = task.userdata['edge_id']
 
     def edge_deploy_result(self, task):
-        if task.status == TaskStatus.COMPLETED:
+        if task.status == ts_const.TaskStatus.COMPLETED:
             task.userdata['jobdata']['edge_deploy_result'] = True
 
     def edge_delete_result(self, task):
-        if task.status == TaskStatus.COMPLETED:
+        if task.status == ts_const.TaskStatus.COMPLETED:
             task.userdata['jobdata']['edge_delete_result'] = True
 
     def snat_create_result(self, task):
-        if task.status == TaskStatus.COMPLETED:
+        if task.status == ts_const.TaskStatus.COMPLETED:
             task.userdata['jobdata']['snat_create_result'] = True
 
     def snat_delete_result(self, task):
-        if task.status == TaskStatus.COMPLETED:
+        if task.status == ts_const.TaskStatus.COMPLETED:
             task.userdata['jobdata']['snat_delete_result'] = True
 
     def dnat_create_result(self, task):
-        if task.status == TaskStatus.COMPLETED:
+        if task.status == ts_const.TaskStatus.COMPLETED:
             task.userdata['jobdata']['dnat_create_result'] = True
 
     def dnat_delete_result(self, task):
-        if task.status == TaskStatus.COMPLETED:
+        if task.status == ts_const.TaskStatus.COMPLETED:
             task.userdata['jobdata']['dnat_delete_result'] = True
 
     def nat_update_result(self, task):
-        if task.status == TaskStatus.COMPLETED:
+        if task.status == ts_const.TaskStatus.COMPLETED:
             task.userdata['jobdata']['nat_update_result'] = True
 
     def routes_update_result(self, task):
-        if task.status == TaskStatus.COMPLETED:
+        if task.status == ts_const.TaskStatus.COMPLETED:
             task.userdata['jobdata']['routes_update_result'] = True
 
     def interface_update_result(self, task):
-        if task.status == TaskStatus.COMPLETED:
+        if task.status == ts_const.TaskStatus.COMPLETED:
             task.userdata['jobdata']['interface_update_result'] = True
 
     def test_deploy_edge(self):
@@ -388,8 +383,8 @@ class VcnsDriverTestCase(base.BaseTestCase):
             'router-id', 'myedge', 'internal-network', jobdata=jobdata,
             wait_for_exec=True)
         self.assertEqual(self.edge_id, 'edge-1')
-        task.wait(TaskState.RESULT)
-        self.assertEqual(task.status, TaskStatus.COMPLETED)
+        task.wait(ts_const.TaskState.RESULT)
+        self.assertEqual(task.status, ts_const.TaskStatus.COMPLETED)
         self.assertTrue(jobdata.get('edge_deploy_result'))
 
     def test_deploy_edge_fail(self):
@@ -397,14 +392,14 @@ class VcnsDriverTestCase(base.BaseTestCase):
             'router-1', 'myedge', 'internal-network', {}, wait_for_exec=True)
         task2 = self.vcns_driver.deploy_edge(
             'router-2', 'myedge', 'internal-network', {}, wait_for_exec=True)
-        task1.wait(TaskState.RESULT)
-        task2.wait(TaskState.RESULT)
-        self.assertEqual(task2.status, TaskStatus.ERROR)
+        task1.wait(ts_const.TaskState.RESULT)
+        task2.wait(ts_const.TaskState.RESULT)
+        self.assertEqual(task2.status, ts_const.TaskStatus.ERROR)
 
     def test_get_edge_status(self):
         self._deploy_edge()
         status = self.vcns_driver.get_edge_status(self.edge_id)
-        self.assertEqual(status, RouterStatus.ROUTER_STATUS_ACTIVE)
+        self.assertEqual(status, vcns_const.RouterStatus.ROUTER_STATUS_ACTIVE)
 
     def test_get_edges(self):
         self._deploy_edge()
@@ -426,7 +421,7 @@ class VcnsDriverTestCase(base.BaseTestCase):
             task = self.vcns_driver.create_dnat_rule(
                 'router-id', edge_id, org, translated, jobdata=jobdata)
             key = 'dnat_create_result'
-        task.wait(TaskState.RESULT)
+        task.wait(ts_const.TaskState.RESULT)
         self.assertTrue(jobdata.get(key))
 
     def _delete_nat_rule(self, edge_id, action, addr):
@@ -439,7 +434,7 @@ class VcnsDriverTestCase(base.BaseTestCase):
             task = self.vcns_driver.delete_dnat_rule(
                 'router-id', edge_id, addr, jobdata=jobdata)
             key = 'dnat_delete_result'
-        task.wait(TaskState.RESULT)
+        task.wait(ts_const.TaskState.RESULT)
         self.assertTrue(jobdata.get(key))
 
     def _test_create_nat_rule(self, action):
@@ -510,7 +505,7 @@ class VcnsDriverTestCase(base.BaseTestCase):
         ]
         task = self.vcns_driver.update_nat_rules(
             'router-id', self.edge_id, snats, dnats, jobdata=jobdata)
-        task.wait(TaskState.RESULT)
+        task.wait(ts_const.TaskState.RESULT)
         self.assertTrue(jobdata.get('nat_update_result'))
 
         natcfg = self.vcns_driver.get_nat_config(self.edge_id)
@@ -554,7 +549,7 @@ class VcnsDriverTestCase(base.BaseTestCase):
         ]
         task = self.vcns_driver.update_routes(
             'router-id', self.edge_id, '10.0.0.1', routes, jobdata=jobdata)
-        task.wait(TaskState.RESULT)
+        task.wait(ts_const.TaskState.RESULT)
         self.assertTrue(jobdata.get('routes_update_result'))
 
     def test_update_interface(self):
@@ -564,7 +559,7 @@ class VcnsDriverTestCase(base.BaseTestCase):
             'router-id', self.edge_id, vcns_const.EXTERNAL_VNIC_INDEX,
             'network-id', address='100.0.0.3', netmask='255.255.255.0',
             jobdata=jobdata)
-        task.wait(TaskState.RESULT)
+        task.wait(ts_const.TaskState.RESULT)
         self.assertTrue(jobdata.get('interface_update_result'))
 
     def test_delete_edge(self):
@@ -572,7 +567,7 @@ class VcnsDriverTestCase(base.BaseTestCase):
         jobdata = {}
         task = self.vcns_driver.delete_edge(
             'router-id', self.edge_id, jobdata=jobdata)
-        task.wait(TaskState.RESULT)
+        task.wait(ts_const.TaskState.RESULT)
         self.assertTrue(jobdata.get('edge_delete_result'))
 
     def test_create_lswitch(self):
